@@ -22,8 +22,6 @@
 #include "kameradevice.moc"
 
 // Define some parts of the old API
-#define SERIAL_SUPPORTED(port) ((port & GP_PORT_SERIAL) != 0)
-#define USB_SUPPORTED(port) ((port & GP_PORT_USB) != 0)
 #define GP_PROMPT_OK 0
 #define GP_PROMPT_CANCEL -1
 
@@ -66,6 +64,7 @@ bool KCamera::initInformation()
 		return false;
 	}
         gp_abilities_list_get_abilities(m_abilitylist, index, &m_abilities);
+	return true;
 }
 
 bool KCamera::initCamera()
@@ -122,7 +121,7 @@ QString KCamera::summary()
 {
 	int result;
 	CameraText	summary;
-	
+
 	initCamera();
 
 	result = gp_camera_get_summary(m_camera, &summary, glob_context);
@@ -135,13 +134,13 @@ bool KCamera::configure()
 {
 	CameraWidget *window;
 	int result;
-	
+
 	initCamera();
 
 	result = gp_camera_get_config(m_camera, &window, glob_context);
 	if (result != GP_OK) {
 		emit error(i18n("Camera configuration failed."), gp_result_as_string(result));
-		return false; 
+		return false;
 	}
 
 	KameraConfigDialog kcd(m_camera, window);
@@ -154,7 +153,7 @@ bool KCamera::configure()
 			return false;
 		}
 	}
-	
+
 	return true;
 }
 
@@ -162,9 +161,7 @@ bool KCamera::test()
 {
 	// TODO: Make testing non-blocking (maybe via KIO?)
 	// Currently, a failed serial test times out at about 30 sec.
-	if (camera()) {
-		return true;
-	}
+	return camera() != 0;
 }
 
 void KCamera::load(KConfig *config)
@@ -231,8 +228,10 @@ QStringList KCamera::supportedPorts()
 {
 	initInformation();
 	QStringList ports;
-	if (SERIAL_SUPPORTED(m_abilities.port)) ports.append("serial");
-	if (USB_SUPPORTED(m_abilities.port)) ports.append("usb");
+	if (m_abilities.port & GP_PORT_SERIAL)
+		ports.append("serial");
+	if (m_abilities.port & GP_PORT_USB)
+		ports.append("usb");
 	return ports;
 }
 
@@ -244,13 +243,13 @@ CameraAbilities KCamera::abilities()
 // ---------- KameraSelectCamera ------------
 
 KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *device)
-	: KDialogBase(parent, "kkameradeviceselect", true, i18n("Select camera device"), Ok | Cancel)
+	: KDialogBase(parent, "kkameradeviceselect", true, i18n("Select Camera Device"), Ok | Cancel)
 {
 	m_device = device;
 	connect(m_device, SIGNAL(error(const QString &)), SLOT(slot_error(const QString &)));
 	connect(m_device, SIGNAL(error(const QString &, const QString &)), SLOT(slot_error(const QString &, const QString &)));
 
-	QWidget *page = new QWidget( this ); 
+	QWidget *page = new QWidget( this );
 	setMainWidget(page);
 
 	// a layout with vertical boxes
@@ -304,7 +303,7 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
 	// serial tab
 	grid = new QGrid(2, m_settingsStack);
 	grid->setSpacing(5);
-	new QLabel(i18n("Port"), grid);
+	new QLabel(i18n("Port:"), grid);
 	m_serialPortCombo = new QComboBox(TRUE, grid);
 	QWhatsThis::add(m_serialPortCombo, i18n("Here you should choose the serial port you connect the camera to."));
 	m_settingsStack->addWidget(grid, INDEX_SERIAL);
@@ -332,12 +331,13 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
 		}
 	}
 	gp_port_info_list_free(list);
-	
+
 	// add a spacer
 	rightLayout->addItem( new QSpacerItem(0, 0, QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding) );
 
 	populateCameraListView();
 	load();
+        enableButtonOK(false );
 }
 
 bool KameraDeviceSelectDialog::populateCameraListView()
@@ -364,12 +364,17 @@ void KameraDeviceSelectDialog::save()
 {
 	m_device->setModel(m_modelSel->currentItem()->text(0));
 
-	QString type = m_portSelectGroup->selected()->text();
+	if (m_portSelectGroup->selected()) {
+		QString type = m_portSelectGroup->selected()->text();
 
-	if(type == i18n("Serial"))
-		m_device->setPath("serial:" + m_serialPortCombo->currentText());
-	else if(type == i18n("USB"))
- 		m_device->setPath("usb:");
+		if(type == i18n("Serial"))
+			m_device->setPath("serial:" + m_serialPortCombo->currentText());
+		else if(type == i18n("USB"))
+ 			m_device->setPath("usb:");
+ 	} else {
+ 		// This camera has no port type (e.g. "Directory Browse" camera).
+ 		// Do nothing.
+ 	}
 }
 
 void KameraDeviceSelectDialog::load()
@@ -379,7 +384,7 @@ void KameraDeviceSelectDialog::load()
 
 	if (port == "serial") setPortType(INDEX_SERIAL);
 	if (port == "usb") setPortType(INDEX_USB);
-	
+
 	QListViewItem *modelItem = m_modelSel->firstChild();
 	do {
 		if (modelItem->text(0) == m_device->model()) {
@@ -391,8 +396,9 @@ void KameraDeviceSelectDialog::load()
 
 void KameraDeviceSelectDialog::slot_setModel(QListViewItem *item)
 {
-	QString model = item->text(0);
-	
+    enableButtonOK( item );
+    QString model = item->text(0);
+
 	CameraAbilities abilities;
 	int index = gp_abilities_list_lookup_model(m_device->m_abilitylist, model.local8Bit().data());
 	if(index < 0) {
@@ -402,19 +408,19 @@ void KameraDeviceSelectDialog::slot_setModel(QListViewItem *item)
 	int result = gp_abilities_list_get_abilities(m_device->m_abilitylist, index, &abilities);
 	if (result == GP_OK) {
 		// enable radiobuttons for supported port types
-		m_serialRB->setEnabled(SERIAL_SUPPORTED(abilities.port));
-		m_USBRB->setEnabled(USB_SUPPORTED(abilities.port));
+		m_serialRB->setEnabled(abilities.port & GP_PORT_SERIAL);
+		m_USBRB->setEnabled(abilities.port & GP_PORT_USB);
 
 		// turn off any selected port
 		QButton *selected = m_portSelectGroup->selected();
 		if(selected != NULL)
 			selected->toggle();
-	
+
 	        // if there's only one available port type, make sure it's selected
-		if ((SERIAL_SUPPORTED(abilities.port)?1:0) + (USB_SUPPORTED(abilities.port)?1:0)) {
-			if (SERIAL_SUPPORTED(abilities.port)) setPortType(INDEX_SERIAL);
-			if (USB_SUPPORTED(abilities.port)) setPortType(INDEX_USB);
-		};
+		if (abilities.port == GP_PORT_SERIAL)
+			setPortType(INDEX_SERIAL);
+		if (abilities.port == GP_PORT_USB)
+			setPortType(INDEX_USB);
 	} else {
 		slot_error(i18n("Description of abilities for camera %1 is not available."
 			     " Configuration options may be incorrect.").arg(model));
