@@ -20,6 +20,10 @@ public:
         virtual void setHost(const QString& host, int port, const QString& user, const QString& pass );
 	virtual void listDir(const KURL &url);
 
+        CameraFile *getFile() { return m_file; }
+        int getFileSize() { return m_fileSize; }
+        void setFileSize(int newfs) { m_fileSize = newfs; }
+
 private:
 	Camera *m_camera;
 	CameraAbilities m_abilities;
@@ -35,7 +39,8 @@ private:
 
 	void statRoot(void);
 	void statRegular(const KURL &url);
-        void translateFileToUDS(KIO::UDSEntry &udsEntry, const CameraFileInfo &info);
+        void translateTextToUDS(KIO::UDSEntry &udsEntry, const QString &info, const char *txt);
+        void translateFileToUDS(KIO::UDSEntry &udsEntry, const CameraFileInfo &info, QString name);
 	void translateDirectoryToUDS(KIO::UDSEntry &udsEntry, const QString &dirname);
 	bool cameraSupportsPreview(void);
 	bool cameraSupportsDel(void);
@@ -48,7 +53,7 @@ private:
 	QString m_cfgModel;
 	QString m_cfgPath;
 
-	CameraFile *m_file;
 	int m_fileSize;
+	CameraFile *m_file;
 };
 #endif
