@@ -1,13 +1,12 @@
+// $Id: font.cpp,v 1.29 2002/09/10 20:04:44 garbanzo Exp $
 
-
+#include <stdio.h>
+#include <stdlib.h>
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <malloc.h>
 #include <qapplication.h>
 #include <qfile.h>
-#include <stdio.h>
-#include <stdlib.h>
 
 #include "dviwin.h"
 #include "font.h"
@@ -28,6 +27,23 @@ extern void oops(QString message);
 #define	VF_ID_BYTE	202
 #define	VF_MAGIC	(VF_PRE << 8) + VF_ID_BYTE
 
+const int font::max_num_of_chars_in_font = 256;
+
+macro::macro()
+{
+  pos     = 0L;		/* address of first byte of macro */
+  end     = 0L;		/* address of last+1 byte */
+  dvi_adv = 0;	/* DVI units to move reference point */
+  free_me =  false;
+}
+
+macro::~macro()
+{
+  if ((pos != 0L) && (free_me == true))
+    delete [] pos;
+}
+
+
 void font::fontNameReceiver(QString fname)
 {
   flags |= font::FONT_LOADED;
@@ -95,16 +111,17 @@ font::~font()
 #endif
 
   if (fontname != 0)
-    free(fontname);
+    delete [] fontname;
+  if (glyphtable != 0)
+    delete [] glyphtable;
+  if (macrotable != 0)
+    delete [] macrotable;
 
   if (flags & FONT_LOADED) {
     if (file != NULL) 
       fclose(file);
-    if (flags & FONT_VIRTUAL) {
-      delete [] macrotable;
+    if (flags & FONT_VIRTUAL)
       vf_table.clear();
-    } else
-      delete [] glyphtable;
   }
 }
 
