@@ -31,12 +31,15 @@ typedef	void	(dviWindow::*set_char_proc)(unsigned int, unsigned int);
 
 // Per character information for virtual fonts
 
-struct macro {
+class macro {
+ public:
+  macro(void);
+  ~macro(void);
+
   unsigned char	*pos;		/* address of first byte of macro */
   unsigned char	*end;		/* address of last+1 byte */
   long	        dvi_adv;	/* DVI units to move reference point */
-  unsigned char	free_me;	/* if free(pos) should be called when */
-				/* freeing space */
+  bool          free_me;        // if memory at pos should be returned on destruction
 };
 
 
@@ -49,7 +52,7 @@ public:
   // this value here, make sure to go through all the source and
   // ensure that character numbers are stored in ints rather than
   // unsigned chars.
-  static const int      max_num_of_chars_in_font = 256;
+  static const int      max_num_of_chars_in_font;
   enum                  font_flags {
                              FONT_IN_USE  = 1,	// used for housekeeping
                              FONT_LOADED  = 2,	// if font file has been read
