@@ -7,12 +7,13 @@
 // Copyright 2000--2001, Stefan Kebekus (stefan.kebekus@uni-bayreuth.de).
 
 
-#include <qfile.h>
-#include <qdir.h>
-#include <qfileinfo.h>
-#include <qstringlist.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kprocio.h>
+#include <qdir.h>
+#include <qfile.h>
+#include <qfileinfo.h>
+#include <qstringlist.h>
 
 #include "dviwin.h"
 #include "kdvi.h"
@@ -24,6 +25,16 @@
 
 extern QPainter foreGroundPaint;
 
+void dviWindow::printErrorMsgForSpecials(QString msg)
+{
+  if (dviFile->errorCounter < 25) {
+    kdError(4300) << msg << endl;
+    dviFile->errorCounter++;
+    if (dviFile->errorCounter == 25)
+      kdError(4300) << i18n("That makes 25 errors. Further error messages will not be printed.") << endl;
+  }
+}
+
 void dviWindow::html_anchor_special(QString cp)
 {
   if (PostScriptOutPutString != NULL) { // only during scanning, not during rendering
@@ -33,11 +44,7 @@ void dviWindow::html_anchor_special(QString cp)
     kdDebug(4300) << "page " << current_page << endl;
 #endif
     
-    AnchorList_String[numAnchors] = cp;
-    AnchorList_Page[numAnchors]   = current_page;
-    AnchorList_Vert[numAnchors]   = DVI_V/65536; // multiply with zoom to get pixel coords
-    if (numAnchors < MAX_ANCHORS-2)
-      numAnchors++;
+    anchorList[cp] = DVI_Anchor(current_page, DVI_V/65536);
   }
 }
 
@@ -166,18 +173,11 @@ void dviWindow::epsf_special(QString cp)
       EPSfilename = fi2.absFilePath();
     else {
       // Use kpsewhich to find the eps file.
-      QString cmd = "kpsewhich ";
-      cmd += KShellProcess::quote(EPSfilename);
-      
-      FILE *fs = popen(QFile::encodeName(cmd).data(), "r");
-      if (fs)
-      {
-        QTextStream ts(fs, IO_ReadOnly);
-        QString KPSEWHICH_EPSfilename = ts.read().stripWhiteSpace();
-	pclose(fs);
-	if (!KPSEWHICH_EPSfilename.isEmpty())
-	  EPSfilename = KPSEWHICH_EPSfilename;
-      }
+      KProcIO proc;
+      proc << "kpsewhich" << EPSfilename;
+      proc.start(KProcess::Block);
+      proc.readln(EPSfilename);
+      EPSfilename = EPSfilename.stripWhiteSpace();
     }
   }
   
@@ -378,6 +378,6 @@ void dviWindow::applicationDoSpecial(char *cp)
     return;
   }
 
-  kdError(4300) << i18n("The special command \"") << special_command << i18n("\" is not implemented.") << endl;
+  printErrorMsgForSpecials(i18n("The special command \"") + special_command + i18n("\" is not implemented."));
   return;
 }
