@@ -1,5 +1,5 @@
 /*
-    $Id: options.cpp,v 1.11 2000/05/24 09:34:32 kulow Exp $
+    $Id: options.cpp,v 1.18 2002/07/01 23:50:32 mhunter Exp $
 
     Requires the Qt widget libraries, available at no cost at
     http://www.troll.no
@@ -34,43 +34,28 @@
 #include "kfax.h"
 #include "options.h"
 
-#define YOFFSET  5
-#define XOFFSET  5
-#define LABLE_LENGTH  40
-#define LABLE_HEIGHT 20
-#define SIZE_X 400
-#define SIZE_Y 280
-#define FONTLABLE_LENGTH 60
-#define COMBO_BOX_HEIGHT 28
-#define COMBO_ADJUST 3
-#define OKBUTTONY 260
-#define BUTTONHEIGHT 25
-
 #include "options.moc"
 
 OptionsDialog::OptionsDialog( QWidget *parent, const char *name)
-    : QDialog( parent, name,TRUE)
+    : KDialogBase( parent, name, true, i18n("Preferences"), Ok|Cancel)
 {
+  QWidget *mainWidget = new QWidget(this);
+  setMainWidget(mainWidget);
 
-  setCaption(i18n("KFax Options Dialog"));
+  QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget, 0, spacingHint());
 
-  this->setFocusPolicy(QWidget::StrongFocus);
-
-  QVBoxLayout *mainLayout = new QVBoxLayout(this, 10);
-
-  bg = new QGroupBox(this,"bg");
+  bg = new QGroupBox(mainWidget,"bg");
+  bg->setColumnLayout( 0, Qt::Horizontal );
   mainLayout->addWidget( bg );
 
-  QVBoxLayout *vbl = new QVBoxLayout(bg, 10);
+  QVBoxLayout *vbl = new QVBoxLayout(bg->layout());
 
   QHBoxLayout *hbl1 = new QHBoxLayout();
-  vbl->addSpacing( 15 );
 
   vbl->addLayout( hbl1 );
 
-  displaylabel = new QLabel(i18n("Display Options:"), bg,"displaylabel");
+  displaylabel = new QLabel(i18n("Display options:"), bg,"displaylabel");
   displaylabel->setFixedSize( displaylabel->sizeHint() );
-  hbl1->addSpacing( 10 );
   hbl1->addWidget( displaylabel );
 
   landscape = new QCheckBox(i18n("Landscape"), bg,"Landscape");
@@ -78,7 +63,7 @@ OptionsDialog::OptionsDialog( QWidget *parent, const char *name)
   hbl1->addSpacing( 10 );
   hbl1->addWidget( landscape );
 
-  flip = new QCheckBox(i18n("Upside Down"), bg,"upsidedown");
+  flip = new QCheckBox(i18n("Upside down"), bg,"upsidedown");
   flip->setFixedSize( flip->sizeHint() );
   hbl1->addSpacing( 10 );
   hbl1->addWidget( flip );
@@ -87,19 +72,20 @@ OptionsDialog::OptionsDialog( QWidget *parent, const char *name)
   invert->setFixedSize( invert->sizeHint() );
   hbl1->addSpacing( 10 );
   hbl1->addWidget( invert );
-  vbl->addSpacing( 15 );
   	
+  vbl->addSpacing( 20 );
+
   QHBoxLayout *hbl8 = new QHBoxLayout();
   vbl->addLayout( hbl8 );
   hbl8->addSpacing( 10 );
-  	
+ 
   resgroup = new QButtonGroup(bg,"resgroup");
   resgroup->setFrameStyle(QFrame::NoFrame);
   hbl8->addWidget( resgroup );
 
   QHBoxLayout *hbl2 = new QHBoxLayout(resgroup);
 
-  reslabel = new QLabel(i18n("Raw Fax Resolution:"),resgroup,"relabel");
+  reslabel = new QLabel(i18n("Raw fax resolution:"),resgroup,"relabel");
   hbl2->addWidget( reslabel );
 
   resauto = new QRadioButton(i18n("Auto"),resgroup,"resauto");
@@ -119,7 +105,7 @@ OptionsDialog::OptionsDialog( QWidget *parent, const char *name)
   QHBoxLayout *hbl3 = new QHBoxLayout();
   vbl->addLayout( hbl3 );
 
-  lsblabel = new QLabel(i18n("Raw Fax Data are:"), bg,"lsblabel");
+  lsblabel = new QLabel(i18n("Raw fax data are:"), bg,"lsblabel");
   hbl3->addSpacing( 10 );
   hbl3->addWidget( lsblabel );
 
@@ -133,29 +119,29 @@ OptionsDialog::OptionsDialog( QWidget *parent, const char *name)
   vbl->addLayout( hbl9 );
   hbl9->addSpacing( 10 );
 
-  rawgroup = new QButtonGroup(this,"rawgroup");
+  rawgroup = new QButtonGroup(bg,"rawgroup");
   hbl9->addWidget( rawgroup );
 
   QHBoxLayout *hbl4 = new QHBoxLayout( rawgroup );
 
   rawgroup->setFrameStyle(QFrame::NoFrame);
 
-  rawlabel = new QLabel(i18n("Raw Facsimili are:"),rawgroup,"rawlabel");
+  rawlabel = new QLabel(i18n("Raw fax format:"),rawgroup,"rawlabel");
   rawlabel->setFixedSize( rawlabel->sizeHint() );
   hbl4->addWidget( rawlabel );
 
-  g3 = new QRadioButton("g3",rawgroup,"g3");
-  connect(g3,SIGNAL(clicked()),this,SLOT(g3toggled()));
+  g3 = new QRadioButton("G3",rawgroup,"g3");
+  connect(g3,SIGNAL(clicked()), this, SLOT(g3toggled()));
   hbl4->addSpacing( 20 );
   hbl4->addWidget( g3 );
 
-  g32d = new QRadioButton("g32d",rawgroup,"g32d");
-  connect(g32d,SIGNAL(clicked()),this,SLOT(g32toggled()));
+  g32d = new QRadioButton("G32d",rawgroup,"g32d");
+  connect(g32d,SIGNAL(clicked()), this,SLOT(g32toggled()));
   hbl4->addSpacing( 30 );
   hbl4->addWidget( g32d );
 
-  g4 = new QRadioButton("g4",rawgroup,"g4");
-  connect(g4,SIGNAL(clicked()),this,SLOT(g4toggled()));
+  g4 = new QRadioButton("G4",rawgroup,"g4");
+  connect(g4,SIGNAL(clicked()), this, SLOT(g4toggled()));
   hbl4->addSpacing( 30 );
   hbl4->addWidget( g4 );
 
@@ -164,44 +150,26 @@ OptionsDialog::OptionsDialog( QWidget *parent, const char *name)
   QHBoxLayout *hbl5 = new QHBoxLayout();
   vbl->addLayout( hbl5 );
 
-  widthlabel = new QLabel(i18n("Raw Fax width:"),this,"widthlabel");
+  widthlabel = new QLabel(i18n("Raw fax width:"),bg,"widthlabel");
   hbl5->addSpacing( 10 );
   hbl5->addWidget( widthlabel );
 
-  widthedit = new KIntNumInput(1, this);
+  widthedit = new KIntNumInput(1, bg);
   widthedit->setRange(1, 10000, 1, false);
   hbl5->addWidget( widthedit );
 
-  heightlabel = new QLabel(i18n("height:"),this,"heightlabel");
+  heightlabel = new QLabel(i18n("Height:"),bg,"heightlabel");
   hbl5->addSpacing( 10 );
   hbl5->addWidget( heightlabel );
 
-  heightedit = new KIntNumInput(1, this);
+  heightedit = new KIntNumInput(1, bg);
   heightedit->setRange(0, 100000, 1, false);
   hbl5->addWidget( heightedit );
 
-  geomauto = new QCheckBox(i18n("Auto"),this,"geomauto");
+  geomauto = new QCheckBox(i18n("Auto"),bg,"geomauto");
   connect(geomauto,SIGNAL(clicked()),this,SLOT(geomtoggled()));
   hbl5->addSpacing( 10 );
   hbl5->addWidget( geomauto );
-
-  QHBoxLayout *hbl6 = new QHBoxLayout();
-//  mainLayout->addStretch( 1 );
-  mainLayout->addLayout( hbl6 );
-
-  cancel_button = new QPushButton(i18n("Cancel"),this);
-  connect( cancel_button, SIGNAL( clicked() ), SLOT( reject() ) );
-
-  ok_button = new QPushButton( i18n("OK"), this );
-  connect( ok_button, SIGNAL( clicked() ), SLOT( ready() ) );	
-
-  helpbutton = new QPushButton(i18n( "Help"), this );
-  connect( helpbutton, SIGNAL( clicked() ), SLOT( help() ) );	
-
-  hbl6->addWidget( ok_button );
-  hbl6->addWidget( cancel_button );
-  hbl6->addStretch( 1 );
-  hbl6->addWidget( helpbutton );
 }
 
 
@@ -386,24 +354,7 @@ void OptionsDialog::geomtoggled(){
 
 }
 
-void OptionsDialog::ready(){
-
-  accept();
-
-}
-
-void OptionsDialog::help(){
-
+void OptionsDialog::slotHelp(){
   kapp->invokeHelp();
-
-}
-
-
-
-
-void OptionsDialog::focusInEvent(QFocusEvent* ){
-
-
-
 }
 
