@@ -1,9 +1,9 @@
 /*
-    $Id: print.cpp,v 1.11 2000/05/24 09:34:32 kulow Exp $
-    
+    $Id: print.cpp,v 1.19 2002/08/11 09:32:24 binner Exp $
+
     KFax -- a fax file viewer for KDE
-       
-    Copyright (C) 1997 Bernd Johannes Wuebben   
+
+    Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
 
     This program is free software; you can redistribute it and/or modify
@@ -19,11 +19,12 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-  
+
 */
 
 #include <stdio.h>
 
+#include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -54,12 +55,12 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name,  bool )
   
   bg = new QButtonGroup(this,"bg");
 
-  lprbutton = new QRadioButton(i18n("Print as Postscript to Printer"),bg,"rawbutton");
+  lprbutton = new QRadioButton(i18n("Print as PostScript to printer"),bg,"rawbutton");
   lprbutton->setGeometry(15,20,250,25);
   lprbutton->setChecked(TRUE);
   connect(lprbutton,SIGNAL(clicked()),this,SLOT(filebuttontoggled()));
   
-  cmdlabel = new QLabel (i18n("Print Command:"),this);
+  cmdlabel = new QLabel (i18n("Print command:"),this);
   cmdlabel->setGeometry(45,60,90,BUTTONHEIGHT);
   cmdlabel->setEnabled(TRUE);
 
@@ -68,13 +69,13 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name,  bool )
   cmdedit->setEnabled(TRUE);
   cmdedit->setText("lpr");
 
-  filebutton = new QRadioButton(i18n("Print as Postscript to File:")
+  filebutton = new QRadioButton(i18n("Print as PostScript to file:")
 				,bg,"commandbutton");
   filebutton->setGeometry(15,90,250,25);
   connect(filebutton,SIGNAL(clicked()),this,SLOT(filebuttontoggled()));
 
 
-  selectfile = new QPushButton (i18n("Browse"),this);
+  selectfile = new QPushButton (i18n("Browse..."),this);
   selectfile->setGeometry(25,140,100,BUTTONHEIGHT);
   selectfile->setEnabled(FALSE);
   connect(selectfile,SIGNAL(clicked()),this,SLOT(choosefile()));
@@ -83,7 +84,7 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name,  bool )
   filename->setGeometry(125,130,215,25);
   filename->setEnabled(FALSE);  
 
-  pagesizelabel = new QLabel (i18n("Page Size:"),bg);
+  pagesizelabel = new QLabel (i18n("Page size:"),bg);
   pagesizelabel->setGeometry(15,175,60,25);
   pagesizelabel->setEnabled(TRUE);
 
@@ -108,7 +109,7 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name,  bool )
   scalebutton->setChecked(FALSE);
 
   marginbutton = 
-    new QCheckBox(i18n("Add Printer Margins (measured in cm):")
+    new QCheckBox(i18n("Add printer margins (measured in cm):")
 		  ,this,"marginbutton");
 
   marginbutton->setGeometry(25,255,300,25);
@@ -135,16 +136,16 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name,  bool )
 
   bg->setGeometry(10,10,380,320);
   
-  cancel_button = new QPushButton(i18n("Cancel"),this);
+  cancel_button = new QPushButton(i18n("&Cancel"),this);
 
   cancel_button->setGeometry( 3*XOFFSET +100, 340, 80, BUTTONHEIGHT );
   connect( cancel_button, SIGNAL( clicked() ), SLOT( cancel() ) );
 
-  ok_button = new QPushButton( i18n("OK"), this );
+  ok_button = new QPushButton( i18n("&OK"), this );
   ok_button->setGeometry( 3*XOFFSET, 340, 80, BUTTONHEIGHT );
   connect( ok_button, SIGNAL( clicked() ), SLOT( ready() ) );	
 
-  help_button = new QPushButton(i18n( "Help"), this );
+  help_button = new QPushButton(i18n( "&Help"), this );
   help_button->setGeometry( 300, 340, 80, BUTTONHEIGHT );
   connect( help_button, SIGNAL( clicked() ), SLOT( help() ) );	
 
@@ -241,7 +242,7 @@ void PrintDialog::setWidgets(struct printinfo* pi ){
       break;
     }
   }
-      
+
 
 }
 
@@ -254,7 +255,7 @@ void PrintDialog::choosefile(){
 
 
 
-  QFileDialog* box = new QFileDialog(this,"printfiledialog",TRUE);
+  KFileDialog* box = new KFileDialog(QString::null,QString::null,this,"printfiledialog",TRUE);
   box->setCaption(i18n("Select Filename"));
 
   if (!box->exec()) {
