@@ -246,7 +246,7 @@ int viewfaxmain()
     args->clear();
 
     if (banner ) {
-      fprintf(stderr, Banner);
+      fputs(Banner, stderr);
       exit(1);
     }
 
