@@ -42,7 +42,7 @@
 
 typedef KGenericFactory<KJpegPlugin> JpegFactory;
 
-K_EXPORT_COMPONENT_FACTORY(kfile_jpeg, JpegFactory("kfile_jpeg"));
+K_EXPORT_COMPONENT_FACTORY(kfile_jpeg, JpegFactory("kfile_jpeg"))
 
 KJpegPlugin::KJpegPlugin(QObject *parent, const char *name,
                        const QStringList &args )
