@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_pdf.cpp,v 1.14.2.1 2002/11/30 09:56:43 lukas Exp $
+ *  $Id: kfile_pdf.cpp,v 1.14.2.2 2003/07/17 15:39:32 mueller Exp $
  */
 
 #include "kfile_pdf.h"
@@ -33,7 +33,7 @@
 
 typedef KGenericFactory<KPdfPlugin> PdfFactory;
 
-K_EXPORT_COMPONENT_FACTORY(kfile_pdf, PdfFactory("kfile_pdf"));
+K_EXPORT_COMPONENT_FACTORY(kfile_pdf, PdfFactory("kfile_pdf"))
 
 KPdfPlugin::KPdfPlugin(QObject *parent, const char *name, const QStringList &preferredItems)
     : KFilePlugin(parent, name, preferredItems)
