@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_png.cpp,v 1.19 2002/10/09 15:10:05 pfeiffer Exp $
+ *  $Id: kfile_png.cpp,v 1.19.2.1 2003/07/17 15:39:32 mueller Exp $
  */
 
 #include <stdlib.h>
@@ -84,7 +84,7 @@ static const char* interlaceModes[] = {
 
 typedef KGenericFactory<KPngPlugin> PngFactory;
 
-K_EXPORT_COMPONENT_FACTORY(kfile_png, PngFactory("kfile_png"));
+K_EXPORT_COMPONENT_FACTORY(kfile_png, PngFactory("kfile_png"))
 
 KPngPlugin::KPngPlugin(QObject *parent, const char *name,
                        const QStringList &args)
