@@ -1,7 +1,5 @@
 /*
- *   kghostview: KDE PostScript viewer
- *   This file: Copyright (C) 2000 Espen Sand, espen@kde.org
- *   Uses ideas from ealier dialog code by Mark Donohoe and Tim Theisen
+ *   Copyright (C) 2000 the KGhostView authors. See file AUTHORS.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,7 +29,7 @@
 // Using KDialogBase in message box mode (gives centered action button)
 //
 InfoDialog::InfoDialog( QWidget *parent, const char *name, bool modal )
-  :KDialogBase( i18n("Document information"), Yes, Yes, Yes, parent,
+  :KDialogBase( i18n("Document Information"), Yes, Yes, Yes, parent,
 		name, modal, true, i18n("&OK") )
 {
   QFrame *page = makeMainWidget();
