@@ -114,11 +114,6 @@ KGVMiniWidget::KGVMiniWidget( KGVPart* part, const char* name ) :
 
 KGVMiniWidget::~KGVMiniWidget()
 {
-    if( mGotoDialog != 0 )
-    {
-	delete mGotoDialog;
-    	mGotoDialog = 0;
-    }
     reset();
 }
 
