@@ -46,12 +46,13 @@
 
 #define PAGELIST_WIDTH 75
 
-K_EXPORT_COMPONENT_FACTORY( libkghostviewpart, KGVFactory );
+K_EXPORT_COMPONENT_FACTORY( libkghostviewpart, KGVFactory )
 
 KGVPart::KGVPart( QWidget* parentWidget, const char*, 
                   QObject* parent, const char* name,
                   const QStringList &args ) :  
     KParts::ReadOnlyPart( parent, name ), 
+    _job( 0 ),
     _mimetypeScanner( 0 ),
     _isGuiInitialized( false ),
     _isDocumentOpen( false ),
@@ -190,7 +191,7 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
                                       actionCollection(), "goToPage" );
 
     //-- PageMarks Menu -----------------------------------------------------
-    new KAction( i18n( "Mark Current Page" ), "flag", CTRL+Key_M,
+    new KAction( i18n( "Mark Current Page" ), "flag", CTRL+SHIFT+Key_M,
                  _markList, SLOT( markCurrent() ),
                  actionCollection(), "mark_current" );
     new KAction( i18n( "Mark &All Pages" ), 0,
@@ -254,6 +255,7 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
 
 KGVPart::~KGVPart()
 {
+    if ( _job ) _job->kill();
     delete _mimetypeScanner;
     writeSettings();
 }
@@ -303,6 +305,10 @@ bool KGVPart::closeURL()
     _psWidget->disableInterpreter(); 
     _isDocumentOpen = false;
     _isFileDirty = false;
+    if ( _job ) {
+	    _job->kill();
+	    _job = 0;
+    }
     if( _mimetypeScanner != 0 )
 	_mimetypeScanner->abort();
     if( !m_file.isEmpty() )
