@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -34,6 +34,7 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
+#include <kprocess.h>
 
 #include "kgv_view.h"
 
@@ -109,6 +110,77 @@ KGVConfigDialog::~KGVConfigDialog()
     writeSettings();
 }
 
+
+    static
+	QString getGSVersion( QString fullPathToExec )
+	{
+	    QString res;
+	    QString chkVersion = KProcess::quote(fullPathToExec) + " --version";
+	    FILE* p = popen( QFile::encodeName(chkVersion), "r" );
+	    if( p ) {
+		// FIXME: a badly configured interpreter can hang us
+		QFile qp;
+		qp.open( IO_ReadOnly, p );
+		qp.readLine( res, 80 );
+		qp.close();
+		pclose( p );
+		res = res.stripWhiteSpace();
+	    }
+	    kdDebug(4500) << "kgvconfigdialog.cpp::{unamed}::getGSVersion() returning " << res <<  endl;
+	    return res;
+	}
+
+
+/* A mechanism for triggering redection of gs versions:
+ *
+ * The idea is that whenever we find we need to workaround a certain version of gs,
+ * we cannot rely that there will solelly be a new kghostviewrc, but that users will
+ * upgrade kghostview. Therefore, whenever we want to trigger redection on a new version,
+ * we increment the counter below. It should have the old value from the previous version
+ * of kghostview and this function will get called.
+ * 
+ */
+
+/* On a related note:
+ * We don't detect upgrades (or downgrades, for that matter) of gs.
+ * I am seeing if I can get the version out of gs as a side effect to displaying a file.
+ * This way, using kconfig:/Ghostscript/GS Version we will see whether the version has changed
+ * and trigger a redetection without the trouble of running "gs --version" on each launch.
+ *
+ * LPC (9 April 2003)
+ */
+const int currentRedetection = 1;
+
+
+/* Here are the issues we found so far in version of gs:
+ *
+ * - gs before 6.50 uses device x11alpha instead of x11
+ * - gs 6.5x does not work well with -dMaxBitmap=...
+ * - gs 8.0 changed the meaning of -dSAFER to -dPARANOIDSAFER and it must be worked around.
+ *
+ */
+
+/* It is not so good to keep version detection in two functions,
+ * but, for now, it will have to do.
+ * 
+ */
+static void redoGSDetection( KConfig* config ) 
+{
+    kdDebug() << "kgvconfigdialog.cpp::{unnamed}::redoGSDetection()" << endl;
+    QString version = getGSVersion( config->readEntry( "Interpreter", "gs" ) );
+    if ( version < QString::number( 7.00 ) ) 
+    {
+	QStringList arguments = QStringList::split( ' ', config->readEntry( "Antialiasing arguments", "" ) );
+	arguments.remove( QString::fromLatin1( "-dMaxBitmap=10000000" ) );
+	QString antiAliasArgs = arguments.join( " " );
+
+	config->writeEntry( "Antialiasing arguments", antiAliasArgs );
+    }
+    config->writeEntry( "GS Version", version );
+    config->writeEntry( "Redetection Counter", currentRedetection );
+    config->sync();
+}
+
 bool KGVConfigDialog::slotConfigureGhostscript()
 {
     kdDebug(4500) << "KGVConfigDialog::slotConfigureGhostscript" << endl;
@@ -117,28 +189,16 @@ bool KGVConfigDialog::slotConfigureGhostscript()
     if( !KStandardDirs::findExe( exe ) ) {
 	return false;
     }
-    QString versionString;
-    QString chkVersion = exe + " --version";
-    FILE* p = popen( chkVersion.local8Bit(), "r" );
-    if( p ) {
-	QFile qp;
-	qp.open( IO_ReadOnly, p );
-	qp.readLine( versionString, 80 );
-	qp.close();
-	pclose( p );
-    }
-    else
-	return false;
-
-    versionString = versionString.stripWhiteSpace();
+    QString versionString = getGSVersion( exe );
+    if ( versionString.isNull() ) return false;
 
     mInterpreterPath = exe;
     mNonAntiAliasArgs = "-sDEVICE=x11";
     mAntiAliasArgs =  versionString < QString::number(6.50)
 		? "-sDEVICE=x11alpha"
-		: "-sDEVICE=x11 -dTextAlphaBits=4 -dGraphicsAlphaBits=2 "
-		  "-dMaxBitmap=10000000";
-
+		: "-sDEVICE=x11 -dTextAlphaBits=4 -dGraphicsAlphaBits=2";
+    // -dMaxBitmap is half broken in gs 6.5x, so only use after 7.00
+    if ( versionString > QString::number( 7.00 ) ) mAntiAliasArgs += " -dMaxBitmap=10000000";
     setup();
 
     return true;
@@ -226,6 +286,9 @@ void KGVConfigDialog::readSettings()
 
     if( config->hasGroup( "Ghostscript" ) ) {
 	config->setGroup( "Ghostscript" );
+	if ( config->readNumEntry( "Redetection Counter", 0 ) < currentRedetection ) {
+	    redoGSDetection( config );
+	}
 	mInterpreterPath = config->readPathEntry( "Interpreter" );
 	mNonAntiAliasArgs = config->readEntry( "Non-antialiasing arguments" );
 	mAntiAliasArgs = config->readEntry( "Antialiasing arguments" );
@@ -235,6 +298,7 @@ void KGVConfigDialog::readSettings()
 	config->writeEntry( "Interpreter", mInterpreterPath );
 	config->writeEntry( "Non-antialiasing arguments", mNonAntiAliasArgs );
 	config->writeEntry( "Antialiasing arguments", mAntiAliasArgs );
+	config->writeEntry( "Redetection Counter", currentRedetection ); // slotConfigureGhostscript() does the checks
 	config->sync();
     }
 
@@ -276,3 +340,5 @@ void KGVConfigDialog::writeSettings()
 }
 
 #include "kgvconfigdialog.moc"
+
+// vim:sw=4:sts=4:ts=8:noet
