@@ -456,6 +456,9 @@ void KPSWidget::setupWidget()
 
 	_backgroundPixmap.resize( size() );
 	_backgroundPixmap.fill( white );
+	// The line below is needed to work around certain "features" of styles such as liquid
+	// see bug:61711 for more info (LPC, 20 Aug '03)
+	setBackgroundOrigin( QWidget::WidgetOrigin );
 	setErasePixmap( _backgroundPixmap );
     }
 
