@@ -70,7 +70,7 @@ uint KColorArray::closestMatch(uint color)
 }
 
 KColorGrid::KColorGrid(QWidget *parent, const char *name, int space)
- : QWidget(parent, name)
+ : QWidget(parent, name, Qt::WResizeNoErase|Qt::WRepaintNoErase)
 {
   //kdDebug() << "KColorGrid - constructor" << endl;
   s = space;
@@ -108,8 +108,10 @@ void KColorGrid::paintEvent(QPaintEvent *e)
   int lastrow  = getY(urect.bottom())+1;
 
   QWMatrix matrix;
+  QPixmap pm(urect.width(),urect.height());
+  pm.fill(paletteBackgroundColor());
   QPainter p;
-  p.begin( this );
+  p.begin( &pm );
 
   firstrow = (firstrow < 0) ? 0 : firstrow;
   firstcol = (firstcol < 0) ? 0 : firstcol;
@@ -128,7 +130,7 @@ void KColorGrid::paintEvent(QPaintEvent *e)
     //  kdDebug() << "Updating row " << i << endl;
     for(int j = firstcol; j < lastcol; j++)
     {
-      matrix.translate( (j*cellsize), (i*cellsize) );
+      matrix.translate( (j*cellsize)-urect.x(), (i*cellsize)-urect.y() );
       p.setWorldMatrix( matrix );
       //p.setClipRect(j*cellsize, i*cellsize, cellsize, cellsize);
       paintCell(&p, i, j);
@@ -139,8 +141,18 @@ void KColorGrid::paintEvent(QPaintEvent *e)
     //kapp->processEvents();
   }
 
+  matrix.translate(-urect.x(),-urect.y());
+  p.setWorldMatrix( matrix );
+  paintForeground(&p,e);
+  
   p.end();
 
+  bitBlt(this,urect.topLeft(),&pm,QRect(0,0,pm.width(),pm.height()));
+
+}
+
+void KColorGrid::paintForeground(QPainter* , QPaintEvent* )
+{
 }
 
 /*
