@@ -49,14 +49,14 @@ KIconEditIcon::~KIconEditIcon()
 }
 
 
-void KIconEditIcon::open(const QImage *image, const QString &xpmName)
+bool KIconEditIcon::open(const QImage *image, const QString &xpmName)
 {
     QImage *img = (QImage*)image;
     QString filename(xpmName);
     KURL _turl(filename);
 
     if(filename.isEmpty())
-        return;
+        return false;
 
     kdDebug() << "KIconEditIcon::open " << filename << endl;
     
@@ -75,7 +75,7 @@ void KIconEditIcon::open(const QImage *image, const QString &xpmName)
         {
             QString msg = i18n("The URL: %1 \nseems to be malformed.\n").arg(_turl.url());
             KMessageBox::sorry((QWidget*)parent(), msg);
-            return;
+            return false;
         }
     }
 
@@ -83,7 +83,7 @@ void KIconEditIcon::open(const QImage *image, const QString &xpmName)
     {
         QString msg = i18n("KIcon: There was a Qt error loading:\n%1\n").arg(_turl.path());
         KMessageBox::error((QWidget*)parent(), msg);
-        return;
+        return false;
     }
 
     kdDebug() << "KIconEditIcon::open - Image loaded" << endl;
@@ -103,11 +103,13 @@ void KIconEditIcon::open(const QImage *image, const QString &xpmName)
     kdDebug() << "newname(_url) : " << _url << endl;    
    
     kdDebug() << "KIconEditIcon::open - done" << endl;
+
+    return true;
 }
 
 
 
-void KIconEditIcon::promptForFile(const QImage *img)
+bool KIconEditIcon::promptForFile(const QImage *img)
 {
     kdDebug() << "KIconEditIcon::promptForFile(const QImage *img)" << endl;
     /*
@@ -121,57 +123,68 @@ void KIconEditIcon::promptForFile(const QImage *img)
   
     KURL url = KFileDialog::getOpenURL( QString::null, filter );
     */
-    KURL url = KFileDialog::getImageOpenURL( QString::null );
+    bool loaded = false;
+    KURL url = KFileDialog::getImageOpenURL( QString::null, static_cast<QWidget *>(parent()) );
 
-    if( url.isEmpty() )
-        return;
-  
-    QString tempFile;
+    if( !url.isEmpty() )
+    {
+        QString tempFile;
 
-    KIO::NetAccess::download( url, tempFile );
-    open( img, tempFile );
-    KIO::NetAccess::removeTempFile( tempFile );
+        if (KIO::NetAccess::download( url, tempFile ))
+        {
+            loaded = open( img, tempFile );
+            KIO::NetAccess::removeTempFile( tempFile );
+        }
+    }
+
+    return loaded;
 }
 
 
 
-void KIconEditIcon::saveAs(const QImage *image)
+bool KIconEditIcon::saveAs(const QImage *image)
 {
     kdDebug() << "KIconEditIcon::saveAs" << endl;
 
     QString file;
 
     //Get list of file types..
-    KFileDialog *dialog=new KFileDialog(QString::null, QString::null, 0L, "file dialog", true);
+    KFileDialog *dialog=new KFileDialog(QString::null, QString::null, static_cast<QWidget *>(parent()), "file dialog", true);
     dialog->setCaption( i18n("Save Icon As") );
     dialog->setKeepLocation( true );
     dialog->setMimeFilter( KImageIO::mimeTypes(KImageIO::Writing), "image/png" );
     dialog->setOperationMode( KFileDialog::Saving );
 
-    if(dialog->exec()==QDialog::Accepted) {
-	file = dialog->selectedFile();
-	if( file.isNull() )
-	    return;
-	if ( !KImageIO::canWrite(KImageIO::type(file)) ) {
-	    if ( KImageIO::canWrite(KImageIO::typeForMime(dialog->currentFilter())) )
-		file += "."+KImageIO::suffix(KImageIO::typeForMime(dialog->currentFilter()));
-	    else
-		file += ".png";
-	}
+    if(dialog->exec()==QDialog::Accepted)
+    {
+        file = dialog->selectedFile();
+        if( file.isNull() )
+        {
+            delete dialog;
+            return false;
+        }
+        if ( !KImageIO::canWrite(KImageIO::type(file)) )
+        {
+            if ( KImageIO::canWrite(KImageIO::typeForMime(dialog->currentFilter())) )
+                file += "."+KImageIO::suffix(KImageIO::typeForMime(dialog->currentFilter()));
+            else
+                file += ".png";
+        }
     }
-    else {
-	delete dialog;
-	return;
+    else
+    {
+        delete dialog;
+        return false;
     }
-	
+        
     delete dialog;
 
-    save( image, file );
+    return save( image, file );
 }
 
 
 
-void KIconEditIcon::save(const QImage *image, const QString &_filename)
+bool KIconEditIcon::save(const QImage *image, const QString &_filename)
 {
     kdDebug() << "KIconEditIcon::save" << endl;
     QString filename = _filename;
@@ -180,8 +193,7 @@ void KIconEditIcon::save(const QImage *image, const QString &_filename)
     {
         if(_url.isEmpty())
         {
-            saveAs(image);
-            return;
+            return saveAs(image);
         }
         else
         {
@@ -193,32 +205,10 @@ void KIconEditIcon::save(const QImage *image, const QString &_filename)
     QImage *img = (QImage*)image;
     img->setAlphaBuffer(true);
     
-    /* jwc - need to fix transparence in reverse by 
-     converting normal background color to 00 in alpha 
-     channel - see fixTransparence in kicongrid.cpp 
-     
-     TRANSPARENT is defined as :
-        QApplication::palette().normal().background().rgb()
-     
-     OPAQUE_MASK is defined as :
-        0xff000000
-     */
-    
-    for(int y = 0; y < img->height(); y++)
-    {
-        uint *l = (uint*)img->scanLine(y);
-        for(int x = 0; x < img->width(); x++, l++)
-        {
-            if(*l == TRANSPARENT)
-            {
-                *l &= ~(OPAQUE_MASK);
-            }
-        }
-    }
-
     KURL turl(filename);
     QString str = turl.path();
-    
+    bool savedOk = false;
+
     /* base image type on file extension - let kimageio
     take care of this determination */
     
@@ -231,7 +221,7 @@ void KIconEditIcon::save(const QImage *image, const QString &_filename)
         // emit signal to change title bar to reflect new name
         emit newname(filename); 
         kdDebug() << "newname(filenamme) : " << _url << endl;    
-        
+        savedOk = true;
     }
     else 
     {
@@ -241,6 +231,8 @@ void KIconEditIcon::save(const QImage *image, const QString &_filename)
     }
 
     kdDebug() << "KIconEditIcon::save - done" << endl;    
+
+    return savedOk;
 }
 
 
