@@ -64,10 +64,10 @@ public:
   void setUrl( const QString & u ) { _url = u; };
 
 public slots:
-  void open(const QImage*, const QString &xpm= QString::null);
-  void promptForFile(const QImage*);
-  void save(const QImage*, const QString &filename=QString::null);
-  void saveAs(const QImage*);
+  bool open(const QImage*, const QString &xpm= QString::null);
+  bool promptForFile(const QImage*);
+  bool save(const QImage*, const QString &filename=QString::null);
+  bool saveAs(const QImage*);
 
 signals:
   void newmessage( const QString &);
