@@ -44,6 +44,7 @@ KIconEdit::KIconEdit(const QImage image, const char *name)
     img = image;
     img.detach();
     grid->load(&img);
+    grid->setModified(true);
     preview->setPixmap(grid->pixmap());
 }
 
@@ -120,6 +121,8 @@ void KIconEdit::init()
            SLOT( slotUpdateStatusMessage(const QString &)));
   connect(grid, SIGNAL(clipboarddata(bool)),
            SLOT( slotUpdatePaste(bool)));
+  connect(grid, SIGNAL(modifiedchanged(bool)),
+           SLOT( slotUpdateStatusModified(bool)));
   gridview->checkClipboard(); //Not very elegant, but fixes a buglet
 
   connect(grid, SIGNAL(selecteddata(bool)),
@@ -144,6 +147,8 @@ void KIconEdit::init()
   if((pprops->winwidth > 0) && (pprops->winheight > 0))
     resize( pprops->winwidth, pprops->winheight );
 
+  updateProperties();
+
   updateAccels();
   show();
 }
@@ -170,7 +175,10 @@ bool KIconEdit::queryClose()
         switch(r)
         {
             case KMessageBox::Yes:
-                icon->save(&grid->image());
+                if (!icon->save(&grid->image()))
+                {
+                    cancel = true;
+                }
                 break;
             case KMessageBox::No:
                 break;
@@ -530,7 +538,7 @@ void KIconEdit::setupTools()
   toolAction->setWhatsThis(i18n("Filled ellipse\n\nDraw a filled ellipse"));
   toolAction->setToolTip(toolAction->text());
 
-  toolAction = new KRadioAction(i18n("Spray"), "spraycan", KShortcut(),
+  toolAction = new KRadioAction(i18n("Spray"), "airbrush", KShortcut(),
                                                     this, SLOT(slotToolSpray()),  actionCollection(), "spray");
   toolAction->setExclusiveGroup("toolActions");
   toolAction->plug(tools);
@@ -538,7 +546,7 @@ void KIconEdit::setupTools()
   toolAction->setWhatsThis(i18n("Spray\n\nDraw scattered pixels in the current color"));
   toolAction->setToolTip(toolAction->text());
 
-  toolAction = new KRadioAction(i18n("Flood Fill"), "flood", KShortcut(),
+  toolAction = new KRadioAction(i18n("Flood Fill"), "fill", KShortcut(),
                                                     this, SLOT(slotToolFlood()),  actionCollection(), "flood");
   toolAction->setExclusiveGroup("toolActions");
   toolAction->plug(tools);
@@ -638,6 +646,7 @@ bool KIconEdit::setupPaletteToolBar()
     preview = new QLabel(palettetoolbar);
     preview->setFrameStyle(QFrame::Panel|QFrame::Sunken);
     preview->setFixedSize(iw, 64);
+    preview->setAlignment(Qt::AlignCenter);
     palettetoolbar->insertWidget(ID_PREVIEW, iw, preview);
     palettetoolbar->insertSeparator();
 
@@ -660,12 +669,18 @@ bool KIconEdit::setupStatusBar()
     Properties *pprops = KIconEditProperties::self()->properties();
     statusbar = statusBar();
 
-    statusbar->insertItem("    -1, -1    ", 0);
-    statusbar->insertItem("   32 x 32   ", 1);
-    statusbar->insertItem(" 1:1000 ", 2);
-    statusbar->insertItem("Colors:       ", 3);
+    statusbar->insertFixedItem("99999,99999", 0, true);
+    statusbar->insertFixedItem("99999 x 99999", 1, true);
+    statusbar->insertFixedItem(" 1:999", 2, true);
+    QString str = i18n("Colors: %1").arg(9999999);
+    statusbar->insertFixedItem(str, 3, true);
     statusbar->insertItem("", 4);
 
+    statusbar->changeItem( "", 0);
+    statusbar->changeItem( "", 1);
+    statusbar->changeItem( "", 2);
+    statusbar->changeItem( "", 3);
+
     if(pprops->statusbarstat)
         statusbar->show();
     else
