@@ -143,6 +143,7 @@ protected slots:
   void slotClearStatusMessage();
   void slotUpdateStatusMessage(const QString &);
   void slotUpdateStatusName(const QString &);
+  void slotUpdateStatusModified(bool);
   void slotUpdateStatusScaling(int, bool);
   void slotUpdatePaste(bool);
   void slotUpdateCopy(bool);
@@ -182,7 +183,8 @@ protected:
   KGridView *gridview;
   KIconEditIcon *icon;
   QImage img;
-  
+  QString m_name;
+
   KAction* actPrint, *actCopy, *actPaste, *actCut;
 };
 
