@@ -53,9 +53,13 @@ void KIconEdit::updateProperties()
                 pix = pmlogo;
             }
             gridview->viewPortWidget()->viewport()->setBackgroundPixmap(pix);
+            preview->setBackgroundPixmap(pix);
         }
         else
+        {
             gridview->viewPortWidget()->viewport()->setBackgroundColor(pprops->backgroundcolor);
+            preview->setBackgroundColor(pprops->backgroundcolor);
+        }
 }
 
 void KIconEdit::addColors(uint n, uint *c)
@@ -95,14 +99,17 @@ void KIconEdit::slotNew()
 
         switch(r)
         {
-            case 0:
-                icon->save(&grid->image());
+            case KMessageBox::Yes:
+                if(!icon->save(&grid->image()))
+                {
+                    cancel = true;
+                }
                 break;
 
-            case 1:
+            case KMessageBox::No:
                 break;
 
-            case 2:
+            case KMessageBox::Cancel:
                 cancel = true;
                 break;
 
@@ -147,14 +154,17 @@ void KIconEdit::slotOpen()
 
         switch( r )
         {
-            case 0:
-                icon->save( &grid->image() );
+            case KMessageBox::Yes:
+                if(!icon->save( &grid->image() ))
+                {
+                    cancel = true;
+                }
                 break;
 
-            case 1:
+            case KMessageBox::No:
                 break;
 
-            case 2:
+            case KMessageBox::Cancel:
                 cancel = true;
                 break;
 
@@ -165,8 +175,10 @@ void KIconEdit::slotOpen()
 
     if( !cancel )
     {
-        icon->promptForFile( &grid->image() );
-        grid->setModified(false);
+        if (icon->promptForFile( &grid->image() ))
+        {
+            grid->setModified(false);
+        }
     }
 }
 
@@ -335,14 +347,17 @@ void KIconEdit::slotOpenRecent(const KURL& iconFile)
 
         switch( r )
         {
-            case 0:
-                icon->save( &grid->image() );
+            case KMessageBox::Yes:
+                if (!icon->save( &grid->image() ))
+                {
+                    cancel = true;
+                }
                 break;
 
-            case 1:
+            case KMessageBox::No:
                 break;
 
-            case 2:
+            case KMessageBox::Cancel:
                 cancel = true;
                 break;
 
@@ -352,13 +367,19 @@ void KIconEdit::slotOpenRecent(const KURL& iconFile)
     }
 
     if( !cancel )
-        icon->open(&grid->image(), iconFile.url());
+    {
+        if(icon->open(&grid->image(), iconFile.url()))
+        {
+            grid->setModified(false);
+        }
+    }
 }
 
 void KIconEdit::slotConfigureSettings()
 {
     KIconConfig* c = new KIconConfig(this);
-    c->show();
+    c->exec();
+    delete c;
 }
 
 void KIconEdit::slotConfigureKeys()
@@ -589,18 +610,27 @@ void KIconEdit::slotClearStatusMessage()
 
 void KIconEdit::slotUpdateStatusName(const QString & name)
 {
-    QString cap = "";
-    if(!name.isEmpty())
+    if(name != m_name)
     {
-        cap += name;
+        addRecent(name);
     }
 
-    // add to list of recent files - this now works -jwc-
-    //kdDebug() << "KIconEdit::slotUpdateStatusName() name is: " << name << endl;
-    addRecent(name);
+    m_name = name;
 
-    // -jwc- do not include app name or dash - kapp takes care of that
-    setCaption(cap);
+    QString text = m_name;
+
+    if(grid->isModified())
+    {
+        text += " *";
+    }
+
+    setCaption(text);
+}
+
+
+void KIconEdit::slotUpdateStatusModified(bool)
+{
+    slotUpdateStatusName(m_name);
 }
 
 
