@@ -31,6 +31,7 @@
 #include <kmessagebox.h>
 #include <kdebug.h>
 
+#include "kiconedit.h"
 #include "kicongrid.h"
 #ifndef PICS_INCLUDED
 #include "pics/logo.xpm"
@@ -100,7 +101,7 @@ KGridView::KGridView(QImage *image, QWidget *parent, const char *name)
 
 void KGridView::paintGrid()
 {
-  _grid->repaint(viewRect(), false);
+  _grid->update(viewRect());
 }
 
 void KGridView::setSizes()
@@ -255,51 +256,6 @@ void KGridView::resizeEvent(QResizeEvent*)
 }
 
 
-/*
-    replace a pixel with alpha channel value less than 0xff,
-    with any transparency at all, with the default background color
-*/
-const QImage *fixTransparence(QImage *image)
-{
-    *image = image->convertDepth(32);
-    image->setAlphaBuffer(true);
-    for(int y = 0; y < image->height(); y++)
-    {
-        uint *l = (uint*)image->scanLine(y);
-        for(int x = 0; x < image->width(); x++, l++)
-        {
-            if(*l < OPAQUE_MASK || *l == (TRANSPARENT|OPAQUE_MASK))
-            {
-                *l = TRANSPARENT;
-            }
-        }
-    }
-    return image;
-}
-
-/*
-    if a pixel is default background color, add alpha value
-    ( QColor ARGB & 00ffffff) to make it transparent in saved image
-*/
-const QImage *saveTransparence(QImage *image)
-{
-    *image = image->convertDepth(32);
-    image->setAlphaBuffer(true);
-    for(int y = 0; y < image->height(); y++)
-    {
-        uint *l = (uint*)image->scanLine(y);
-        for(int x = 0; x < image->width(); x++, l++)
-        {
-            if(*l == TRANSPARENT)
-            {
-                *l &= ~(TRANSPARENT);
-            }
-        }
-    }
-    return image;
-}
-
-
 KIconEditGrid::KIconEditGrid(QImage *image, QWidget *parent, const char *name)
  : KColorGrid(parent, name, 1)
 {
@@ -316,7 +272,8 @@ KIconEditGrid::KIconEditGrid(QImage *image, QWidget *parent, const char *name)
     btndown = isselecting = ispasting = modified = false;
 
     img->create(32, 32, 32);
-    img->fill(TRANSPARENT);
+    img->setAlphaBuffer(true);
+    clearImage(img);
 
     currentcolor = qRgb(0,0,0)|OPAQUE_MASK;
 
@@ -339,7 +296,11 @@ void KIconEditGrid::paintEvent(QPaintEvent *e)
 {
     //kdDebug() << "KIconGrid::paintEvent" << endl;
     KColorGrid::paintEvent(e);
+    //kdDebug() << "KIconGrid::paintEvent - done" << endl;
+}
 
+void KIconEditGrid::paintForeground(QPainter* p, QPaintEvent* e)
+{
     if(hasGrid()&& !(cellSize()==1))
     {
         int x = e->rect().x() - ((e->rect().x() % cellSize()) + cellSize());
@@ -349,19 +310,13 @@ void KIconEditGrid::paintEvent(QPaintEvent *e)
         int cx = e->rect().right() + cellSize();
         int cy = e->rect().bottom() + cellSize();
 
-        QPainter p;
-        p.begin( this );
-
         // draw grid lines
         for(int i = x; i < cx; i += cellSize())
-            p.drawLine(i, y, i, cy);
+            p->drawLine(i, y, i, cy);
 
         for(int i = y; i < cy; i += cellSize())
-            p.drawLine(x, i, cx, i);
-
-        p.end();
+            p->drawLine(x, i, cx, i);
     }
-    //kdDebug() << "KIconGrid::paintEvent - done" << endl;
 }
 
 
@@ -369,7 +324,16 @@ void KIconEditGrid::paintCell( QPainter *painter, int row, int col )
 {
   int sel = row * numCols() + col;
   int s = cellSize();
-  uint c = colorAt(sel);
+  uint sourcePixel = colorAt(sel);
+  uint backgroundColour = eraseColor().rgb();
+
+  double alpha = qAlpha(sourcePixel) / 255.0;
+
+  int r = (int) (((qRed(backgroundColour) * (1 - alpha)) + (qRed(sourcePixel) * alpha)) + 0.5);
+  int g = (int) (((qGreen(backgroundColour) * (1 - alpha)) + (qGreen(sourcePixel) * alpha)) + 0.5);
+  int b = (int) (((qBlue(backgroundColour) * (1 - alpha)) + (qBlue(sourcePixel) * alpha)) + 0.5);
+
+  uint c = qRgb(r, g, b);
 
   if(s == 1)
   {
@@ -480,9 +444,6 @@ void KIconEditGrid::mouseMoveEvent( QMouseEvent *e )
     int col = findCol( e->pos().x() );
     int cell = row * numCols() + col;
 
-    QPoint tmpp(col, row);
-    if(tmpp == end) return;
-
     if(img->valid(col, row))
     {
         //kdDebug() << col << " X " << row << endl;
@@ -492,6 +453,9 @@ void KIconEditGrid::mouseMoveEvent( QMouseEvent *e )
         emit yposchanged((row*scaling())+scaling()/2);
     }
 
+    QPoint tmpp(col, row);
+    if(tmpp == end) return;
+
     // need to use intersection of rectangles to allow pasting
     // only that part of clip image which intersects -jwc-
     if(ispasting && !btndown && img->valid(col, row))
@@ -542,11 +506,11 @@ void KIconEditGrid::mouseMoveEvent( QMouseEvent *e )
 
             if ( selected != cell )
             {
-                modified = true;
+                setModified( true );
                 int prevSel = selected;
                 selected = cell;
-                repaint((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize, false);
-                repaint(col*cellsize,row*cellsize, cellsize, cellsize, false);
+                update((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize);
+                update(col*cellsize,row*cellsize, cellsize, cellsize);
                 *((uint*)img->scanLine(row) + col) = (colorAt(cell));
             }
             break;
@@ -558,8 +522,8 @@ void KIconEditGrid::mouseMoveEvent( QMouseEvent *e )
             {
                 int prevSel = selected;
                 selected = cell;
-                repaint((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize, false);
-                repaint(col*cellsize,row*cellsize, cellsize, cellsize, false);
+                update((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize);
+                update(col*cellsize,row*cellsize, cellsize, cellsize);
             }
             break;
         }
@@ -585,7 +549,7 @@ void KIconEditGrid::mouseMoveEvent( QMouseEvent *e )
         case Spray:
         {
             drawSpray(QPoint(col, row));
-            modified = true;
+            setModified(true);
             break;
         }
         default:
@@ -623,11 +587,11 @@ void KIconEditGrid::mouseReleaseEvent( QMouseEvent *e )
         setColor( cell, currentcolor );
       //if ( selected != cell )
       //{
-        //modified = true;
+        setModified( true );
         int prevSel = selected;
         selected = cell;
-        repaint((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize, false);
-        repaint(col*cellsize,row*cellsize, cellsize, cellsize, false);
+        update((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize);
+        update(col*cellsize,row*cellsize, cellsize, cellsize);
         //updateCell( prevSel/numCols(), prevSel%numCols(), FALSE );
         //updateCell( row, col, FALSE );
         *((uint*)img->scanLine(row) + col) = colorAt(cell);
@@ -676,8 +640,8 @@ void KIconEditGrid::mouseReleaseEvent( QMouseEvent *e )
       {
         int prevSel = selected;
         selected = cell;
-        repaint((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize, false);
-        repaint(col*cellsize,row*cellsize, cellsize, cellsize, false);
+        update((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize);
+        update(col*cellsize,row*cellsize, cellsize, cellsize);
         //updateCell( prevSel/numCols(), prevSel%numCols(), FALSE );
         //updateCell( row, col, FALSE );
       }
@@ -700,7 +664,8 @@ void KIconEditGrid::setColorSelection( uint c )
 void KIconEditGrid::loadBlank( int w, int h )
 {
   img->create(w, h, 32);
-  img->fill(TRANSPARENT);
+  img->setAlphaBuffer(true);
+  clearImage(img);
   setNumRows(h);
   setNumCols(w);
   fill(TRANSPARENT);
@@ -712,21 +677,19 @@ void KIconEditGrid::loadBlank( int w, int h )
 
 void KIconEditGrid::load( QImage *image)
 {
-  kdDebug() << "KIconEditGrid::load" << endl;
+    kdDebug() << "KIconEditGrid::load" << endl;
 
     setUpdatesEnabled(false);
 
-    if(image != 0L)
-    {
-        *img = *fixTransparence(image);
-    }
-    else
+    if(image == 0L)
     {
         QString msg = i18n("There was an error loading a blank image.\n");
         KMessageBox::error(this, msg);
         return;
     }
 
+    *img = image->convertDepth(32);
+    img->setAlphaBuffer(true);
     setNumRows(img->height());
     setNumCols(img->width());
 
@@ -858,10 +821,10 @@ void KIconEditGrid::editSelectAll()
 
 void KIconEditGrid::editClear()
 {
-    img->fill(TRANSPARENT);
+    clearImage(img);
     fill(TRANSPARENT);
     update();
-    modified = true;
+    setModified(true);
     p = *img;
     emit changed(p);
     emit newmessage(i18n("Cleared"));
@@ -874,7 +837,8 @@ QImage KIconEditGrid::getSelection(bool cut)
     rect.rect(&nx, &ny, &nw, &nh);
 
     QImage tmp(nw, nh, 32);
-    tmp.fill(TRANSPARENT);
+    tmp.setAlphaBuffer(true);
+    clearImage(&tmp);
 
     int s = pntarray.size();
 
@@ -900,12 +864,13 @@ QImage KIconEditGrid::getSelection(bool cut)
     if(cut)
     {
         updateColors();
-        repaint(rect.x()*cellSize(), rect.y()*cellSize(),
-            rect.width()*cellSize(), rect.height()*cellSize(), false);
+        update(rect.x()*cellSize(), rect.y()*cellSize(),
+            rect.width()*cellSize(), rect.height()*cellSize());
         p = *img;
         emit changed(p);
         emit colorschanged(numColors(), data());
         emit newmessage(i18n("Selected area cut"));
+        setModified(true);
     }
     else
         emit newmessage(i18n("Selected area copied"));
@@ -924,7 +889,6 @@ void KIconEditGrid::editPaste(bool paste)
 {
     bool ok = false;
     QImage tmp = clipboardImage(ok);
-    fixTransparence(&tmp);
 
     Properties *pprops = KIconEditProperties::self()->properties();
 
@@ -958,20 +922,97 @@ void KIconEditGrid::editPaste(bool paste)
                 uint *cl = (uint*)tmp.scanLine(ny);
                 for(int x = insrect.x(), nx = 0; x < numCols(), nx < insrect.width(); x++, nx++, l++, cl++)
                 {
-                    if(*cl != TRANSPARENT || pprops->pastetransparent)
+                    if(pprops->pastetransparent)
                     {
                         *l = *cl;
-                        setColor((y*numCols())+x, (uint)*cl, false);
                     }
+                    else
+                    {
+                        // Porter-Duff Over composition
+                        double alphaS = qAlpha(*cl) / 255.0;
+                        double alphaD = qAlpha(*l) / 255.0;
+                        
+                        double r = qRed(*cl) * alphaS + (1 - alphaS) * qRed(*l) * alphaD;
+                        double g = qGreen(*cl) * alphaS + (1 - alphaS) * qGreen(*l) * alphaD;
+                        double b = qBlue(*cl) * alphaS + (1 - alphaS) * qBlue(*l) * alphaD;
+                        double a = alphaS + (1 - alphaS) * alphaD;
+                        
+                        // Remove multiplication by alpha
+                        
+                        if(a > 0)
+                        {
+                            r /= a;
+                            g /= a;
+                            b /= a;
+                        }
+                        else
+                        {
+                            r = 0;
+                            g = 0;
+                            b = 0;
+                        }
+                        
+                        int ir = (int)(r + 0.5);
+                        
+                        if(ir < 0)
+                        {
+                            ir = 0;
+                        }
+                        else
+                        if(ir > 255)
+                        {
+                            ir = 255;
+                        }
+                        
+                        int ig = (int)(g + 0.5);
+                        
+                        if(ig < 0)
+                        {
+                            ig = 0;
+                        }
+                        else
+                        if(ig > 255)
+                        {
+                            ig = 255;
+                        }
+                        
+                        int ib = (int)(b + 0.5);
+                        
+                        if(ib < 0)
+                        {
+                            ib = 0;
+                        }
+                        else
+                        if(ib > 255)
+                        {
+                            ib = 255;
+                        }
+                        
+                        int ia = (int)((a * 255) + 0.5);
+                        
+                        if(ia < 0)
+                        {
+                            ia = 0;
+                        }
+                        else
+                        if(ia > 255)
+                        {
+                            ia = 255;
+                        }
+                        
+                        *l = qRgba(ir, ig, ib, ia);
+                    }
+                    
+                    setColor((y*numCols())+x, (uint)*l, false);
                 }
             }
             updateColors();
-            repaint(insrect.x()*cellSize(), insrect.y()*cellSize(),
-                insrect.width()*cellSize(), insrect.height()*cellSize(), false);
+            update(insrect.x()*cellSize(), insrect.y()*cellSize(),
+                insrect.width()*cellSize(), insrect.height()*cellSize());
 
             QApplication::restoreOverrideCursor();
 
-            modified = true;
+            setModified(true);
             p = *img;
             emit changed(QPixmap(p));
             emit sizechanged(numCols(), numRows());
@@ -994,16 +1035,24 @@ void KIconEditGrid::editPasteAsNew()
 
     if(ok)
     {
-        *img = tmp;
-        load(img);
-        modified = true;
-        //repaint(viewRect(), false);
-
-        p = *img;
-        emit changed(QPixmap(p));
-        emit sizechanged(numCols(), numRows());
-        emit colorschanged(numColors(), data());
-        emit newmessage(i18n("Done pasting"));
+        if(isModified())
+        {
+            KIconEdit *w = new KIconEdit(tmp);
+            Q_CHECK_PTR(w);
+        }
+        else
+        {
+            *img = tmp;
+            load(img);
+            setModified(true);
+            //repaint(viewRect(), false);
+  
+            p = *img;
+            emit changed(QPixmap(p));
+            emit sizechanged(numCols(), numRows());
+            emit colorschanged(numColors(), data());
+            emit newmessage(i18n("Done pasting"));
+        }
     }
     else
     {
@@ -1023,7 +1072,7 @@ void KIconEditGrid::editResize()
         *img = img->smoothScale(s.width(), s.height());
         load(img);
 
-        modified = true;
+        setModified(true);
     }
     delete rs;
 }
@@ -1034,7 +1083,8 @@ void KIconEditGrid::setSize(const QSize s)
     kdDebug() << "::setSize: " << s.width() << " x " << s.height() << endl;
 
     img->create(s.width(), s.height(), 32);
-    img->fill(TRANSPARENT);
+    img->setAlphaBuffer(true);
+    clearImage(img);
     load(img);
 }
 
@@ -1046,6 +1096,19 @@ void KIconEditGrid::createCursors()
 
   cursor_normal = QCursor(arrowCursor);
 
+  pix = BarIcon("colorpicker-cursor");
+  if(pix.isNull())
+  {
+    cursor_colorpicker = cursor_normal;
+    kdDebug() << "KIconEditGrid: Error loading colorpicker-cursor.xpm" << endl;
+  }
+  else
+  {
+    mask = pix.createHeuristicMask();
+    pix.setMask(mask);
+    cursor_colorpicker = QCursor(pix, 1, 21);
+  }
+
   pix = BarIcon("paintbrush-cursor");
   if(pix.isNull())
   {
@@ -1056,20 +1119,20 @@ void KIconEditGrid::createCursors()
   {
     mask = pix.createHeuristicMask();
     pix.setMask(mask);
-    cursor_paint = QCursor(pix, 6, 18);
+    cursor_paint = QCursor(pix, 0, 19);
   }
 
-  pix = BarIcon("flood-cursor");
+  pix = BarIcon("fill-cursor");
   if(pix.isNull())
   {
     cursor_flood = cursor_normal;
-    kdDebug() << "KIconEditGrid: Error loading flood-cursor.xpm" << endl;
+    kdDebug() << "KIconEditGrid: Error loading fill-cursor.xpm" << endl;
   }
   else
   {
     mask = pix.createHeuristicMask();
     pix.setMask(mask);
-    cursor_flood = QCursor(pix, 5, 16);
+    cursor_flood = QCursor(pix, 3, 20);
   }
 
   pix = BarIcon("aim-cursor");
@@ -1082,20 +1145,20 @@ void KIconEditGrid::createCursors()
   {
     mask = pix.createHeuristicMask();
     pix.setMask(mask);
-    cursor_aim = QCursor(pix);
+    cursor_aim = QCursor(pix, 10, 10);
   }
 
-  pix = BarIcon("spraycan-cursor");
+  pix = BarIcon("airbrush-cursor");
   if(pix.isNull())
   {
     cursor_spray = cursor_normal;
-    kdDebug() << "KIconEditGrid: Error loading spraycan-cursor.xpm" << endl;
+    kdDebug() << "KIconEditGrid: Error loading airbrush-cursor.xpm" << endl;
   }
   else
   {
     mask = pix.createHeuristicMask(true);
     pix.setMask(mask);
-    cursor_spray = QCursor(pix);
+    cursor_spray = QCursor(pix, 0, 20);
   }
 
   pix = BarIcon("eraser-cursor");
@@ -1154,7 +1217,7 @@ void KIconEditGrid::setTool(DrawTool t)
             setCursor(cursor_flood);
             break;
         case Find:
-            setCursor(arrowCursor);
+            setCursor(cursor_colorpicker);
             break;
         default:
             break;
@@ -1172,6 +1235,8 @@ void KIconEditGrid::drawFlood(int x, int y, uint oldcolor)
     *((uint*)img->scanLine(y) + x) = currentcolor;
     setColor((y*numCols())+x, currentcolor, false);
 
+    setModified(true);
+
     drawFlood(x, y-1, oldcolor);
     drawFlood(x, y+1, oldcolor);
     drawFlood(x-1, y, oldcolor);
@@ -1488,7 +1553,7 @@ void KIconEditGrid::drawLine(bool drawit, bool drawStraight)
 void KIconEditGrid::drawPointArray(QPointArray a, DrawAction action)
 {
     QRect rect = a.boundingRect();
-    bool update = false;
+    bool doupdate = false;
 
     int s = a.size(); //((rect.size().width()) * (rect.size().height()));
     for(int i = 0; i < s; i++)
@@ -1506,15 +1571,15 @@ void KIconEditGrid::drawPointArray(QPointArray a, DrawAction action)
                     *((uint*)img->scanLine(y) + x) = currentcolor; //colors[cell]|OPAQUE;
                     int cell = y * numCols() + x;
                     setColor( cell, currentcolor, false );
-                    modified = true;
-                    update = true;
+                    setModified( true );
+                    doupdate = true;
                     //updateCell( y, x, FALSE );
                     break;
                 }
 
                 case Mark:
                 case UnMark:
-                    repaint(x*cellsize,y*cellsize, cellsize, cellsize, false);
+                    update(x*cellsize,y*cellsize, cellsize, cellsize);
                     //updateCell( y, x, true );
                     break;
 
@@ -1524,11 +1589,11 @@ void KIconEditGrid::drawPointArray(QPointArray a, DrawAction action)
         }
     }
 
-    if(update)
+    if(doupdate)
     {
         updateColors();
-        repaint(rect.x()*cellSize()-1, rect.y()*cellSize()-1,
-            rect.width()*cellSize()+1, rect.height()*cellSize()+1, false);
+        update(rect.x()*cellSize()-1, rect.y()*cellSize()-1,
+            rect.width()*cellSize()+1, rect.height()*cellSize()+1);
         pntarray.resize(0);
     }
 
@@ -1778,7 +1843,7 @@ void KIconEditGrid::mapToKDEPalette()
     }
 
     load(img);
-    modified = true;
+    setModified(true);
     QApplication::restoreOverrideCursor();
 }
 
@@ -1792,13 +1857,47 @@ void KIconEditGrid::grayScale()
         {
             if(*l != TRANSPARENT)
             {
-                uint c = (qBlue(*l) + qRed(*l) + qGreen(*l))/3;
-                *l = QColor(c, c, c).rgb()|OPAQUE_MASK;
+                uint c = qGray(*l);
+                *l = qRgba(c, c, c, qAlpha(*l));
             }
         }
     }
 
     load(img);
-    modified = true;
+    setModified(true);
 }
+
+
+void KIconEditGrid::clearImage(QImage *image)
+{
+    if(image->depth() != 32)
+    {
+        image->fill(TRANSPARENT);
+    }
+    else
+    {
+        // QImage::fill() does not set the alpha channel so do it
+        // manually.
+        for(int y = 0; y < image->height(); y++)
+        {
+            uint *l = (uint*)image->scanLine(y);
+            for(int x = 0; x < image->width(); x++, l++)
+            {
+                *l = TRANSPARENT;
+            }
+        }
+    }
+}
+
+
+void KIconEditGrid::setModified(bool m)
+{
+    if(m != modified)
+    {
+        modified = m;
+        emit modifiedchanged(m);
+    }
+}
+
+
 #include "kicongrid.moc"
