@@ -107,7 +107,7 @@ public:
 
   void setGrid(bool g) { KColorGrid::setGrid(g); emit needPainting(); }
   bool isModified() { return modified; };
-  void setModified(bool m) { modified = m; }
+  void setModified(bool m);
   const QPixmap &pixmap();
   const QImage &image() { return *img; }
   QImage clipboardImage(bool &ok);
@@ -153,6 +153,7 @@ signals:
   void clipboarddata(bool);
   void selecteddata(bool);
   void needPainting();
+  void modifiedchanged(bool);
 
 protected slots:
   void setColorSelection( uint );
@@ -161,6 +162,7 @@ protected slots:
 protected:
   virtual void paintEvent(QPaintEvent*);
   virtual void paintCell( QPainter*, int, int );
+  virtual void paintForeground(QPainter* p, QPaintEvent* e);
   virtual void mousePressEvent(QMouseEvent*);
   virtual void mouseReleaseEvent(QMouseEvent*);
   virtual void mouseMoveEvent(QMouseEvent*);
@@ -171,6 +173,7 @@ protected:
   void drawRect(bool);
   void drawSpray(QPoint);
   void drawFlood(int x, int y, uint oldcolor);
+  static void clearImage(QImage *image);
 
   uint currentcolor;
   QPoint start, end;
@@ -182,7 +185,7 @@ protected:
   bool modified, btndown, ispasting, isselecting;
   QPointArray pntarray;
   KColorArray iconcolors;
-  QCursor cursor_normal, cursor_aim, cursor_flood, cursor_spray, cursor_erase, cursor_paint;
+  QCursor cursor_normal, cursor_aim, cursor_flood, cursor_spray, cursor_erase, cursor_paint, cursor_colorpicker;
 };
 
 
