@@ -29,59 +29,72 @@
 
 #include "knew.h"
 
+KIconTemplateContainer* KIconTemplateContainer::instance = 0;
+
 void createStandardTemplates(KIconTemplateContainer *list)
 {
     KIconLoader *kil = KGlobal::iconLoader();
 
-    KIconTemplate *it = new KIconTemplate;
-    it->path = kil->iconPath("standard", KIcon::User);
-    it->title = i18n("Standard file");
+    KIconTemplate it;
+    it.path = kil->iconPath("standard", KIcon::User);
+    it.title = i18n("Standard File");
+    list->append(it);
+    
+    it.path = kil->iconPath("source", KIcon::User);
+    it.title = i18n("Source File");
     list->append(it);
 
-    it = new KIconTemplate;
-    it->path = kil->iconPath("source", KIcon::User);
-    it->title = i18n("Source file");
+    it.path = kil->iconPath("compressed", KIcon::User);
+    it.title = i18n("Compressed File");
     list->append(it);
 
-    it = new KIconTemplate;
-    it->path = kil->iconPath("compressed", KIcon::User);
-    it->title = i18n("Compressed file");
+    it.path = kil->iconPath("folder", KIcon::User);
+    it.title = i18n("Standard Folder");
     list->append(it);
 
-    it = new KIconTemplate;
-    it->path = kil->iconPath("folder", KIcon::User);
-    it->title = i18n("Standard folder");
+    it.path = kil->iconPath("package", KIcon::User);
+    it.title = i18n("Standard Package");
     list->append(it);
 
-    it = new KIconTemplate;
-    it->path = kil->iconPath("package", KIcon::User);
-    it->title = i18n("Standard package");
+    it.path = kil->iconPath("mini-folder", KIcon::User);
+    it.title = i18n("Mini Folder");
     list->append(it);
 
-    it = new KIconTemplate;
-    it->path = kil->iconPath("mini-folder", KIcon::User);
-    it->title = i18n("Mini folder");
-    list->append(it);
-
-    it = new KIconTemplate;
-    it->path = kil->iconPath("mini-package", KIcon::User);
-    it->title = i18n("Mini package");
+    it.path = kil->iconPath("mini-package", KIcon::User);
+    it.title = i18n("Mini Package");
     list->append(it);
 }
 
-KIconTemplateContainer::KIconTemplateContainer() : QPtrList<KIconTemplate>()
+void KIconTemplateContainer::save()
 {
-  setAutoDelete(true);
+  KConfig *k = kapp->config();
+  k->setGroup("Templates");
+  
+  QStringList names;
+  for (QValueListIterator<KIconTemplate> iter = begin(); iter != end(); iter++)
+  {
+      names.append((*iter).title);
+  }
+  
+  k->writeEntry("Names",  names);
+  
+  for(unsigned int i = 0; i < names.count(); i++)
+  {    
+    k->writeEntry(names[i], (*this)[i].path);
+  }
+}
 
+KIconTemplateContainer::KIconTemplateContainer() : QValueList<KIconTemplate>()
+{  
   QStrList names;
   KConfig *k = kapp->config();
   k->setGroup("Templates");
   k->readListEntry("Names", names);
   for(int i = 0; i < (int)names.count(); i++)
   {
-    KIconTemplate *it = new KIconTemplate;
-    it->path = k->readEntry(names.at(i));
-    it->title = names.at(i);
+    KIconTemplate it;
+    it.path = k->readEntry(names.at(i));
+    it.title = names.at(i);
     //kdDebug() << "Template: " << names.at(i) << "\n" << path.data() << endl;
     append(it);
   }
@@ -97,15 +110,23 @@ KIconTemplateContainer::~KIconTemplateContainer()
   clear();
 }
 
-KIconListBoxItem::KIconListBoxItem( KIconTemplate *t )
-   : QListBoxItem()
+KIconListBoxItem::KIconListBoxItem( KIconTemplate t )
+   : QListBoxItem(), icontemplate(t)
 {
   //kdDebug() << "KIconListBoxItem - " << t->path.data() << ", " << t->title.data() << endl;
-  icontemplate = t;
-  pm.load(t->path);
-  setText( t->title );
+ 
+  pm.load(t.path);
+  setText( t.title );
 }
 
+void KIconListBoxItem::reloadIcon()
+{
+  pm.load(icontemplate.path);
+  setText( icontemplate.title );
+}
+ 
+
+
 void KIconListBoxItem::paint( QPainter *p )
 {
   p->drawPixmap( 3, 0, pm );
@@ -135,7 +156,7 @@ NewSelect::NewSelect(QWidget *parent) : QWidget( parent )
   connect( grp, SIGNAL( clicked( int ) ), SLOT( buttonClicked( int ) ) );
   grp->setExclusive( true );
   
-  QVBoxLayout* ml = new QVBoxLayout( this, 10 );
+  QVBoxLayout* ml = new QVBoxLayout( this );
   ml->addWidget( grp, 1 );
   //ml->addWidget(grp, 10, AlignLeft);
   QVBoxLayout* l = new QVBoxLayout( grp, 10 );
@@ -169,7 +190,7 @@ NewFromTemplate::NewFromTemplate( QWidget* parent )
 {
   wiz = (KWizard*) parent;
   
-  QVBoxLayout* ml = new QVBoxLayout(this, 10);
+  QVBoxLayout* ml = new QVBoxLayout(this);
   
   grp = new QGroupBox( i18n( "Templates:" ), this );
   ml->addWidget( grp, 1 );
@@ -180,13 +201,9 @@ NewFromTemplate::NewFromTemplate( QWidget* parent )
   templates = new KIconListBox( grp );
   connect( templates, SIGNAL( highlighted( int ) ), SLOT( checkSelection( int ) ) );
   l->addWidget( templates );
-  
-  KIconTemplateContainer *tlist = new KIconTemplateContainer();
-
-  for( int i = 0; i < (int) tlist->count(); i++ )
-    templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
-
-  delete tlist;
+    
+  for( int i = 0; i < (int) KIconTemplateContainer::self()->count(); i++ )
+    templates->insertItem( new KIconListBoxItem( *KIconTemplateContainer::self()->at( i ) ) );
 }
 
 NewFromTemplate::~NewFromTemplate()
@@ -227,10 +244,10 @@ KNewIcon::KNewIcon( QWidget* parent )
   templ = new NewFromTemplate(this);
   templ->hide();
 
-  addPage(select, i18n("Select icontype"));
-  addPage(scratch, i18n("Create from scratch"));
+  addPage(select, i18n("Select Icon Type"));
+  addPage(scratch, i18n("Create From Scratch"));
   act = scratch;
-  //addPage(templ, i18n("Create from template"));
+  //addPage(templ, i18n("Create From Template"));
 }
 
 KNewIcon::~KNewIcon()
@@ -269,22 +286,22 @@ void KNewIcon::iconOpenStyle(int style)
   {
     act = scratch;
     setNextEnabled( act, true );
-    addPage( scratch, i18n( "Create from scratch" ) );
+    addPage( scratch, i18n( "Create From Scratch" ) );
   }
   else if( openstyle == Template )
   {
     act = templ;
     setNextEnabled( act, true );
-    addPage( templ, i18n( "Create from template" ) );
+    addPage( templ, i18n( "Create From Template" ) );
   }
 }
 
-void KNewIcon::checkPage(int p)
+void KNewIcon::checkPage( bool b)
 {
     //kdDebug() << "checkPage(int) " << openstyle << " " << p << endl;
     if(openstyle == Blank)
         finishButton()->setEnabled(true);
-    else if(p == 0)
+    else if( !b )
         finishButton()->setEnabled(false);
     else
         templ->checkSelection(0);
