@@ -39,12 +39,12 @@ void setupImageHandlers()
   formats = new imageFormats;
   Q_CHECK_PTR(formats);
   formats->setAutoDelete(true);
-  formats->append(new imageFormat("GIF", "Gif",  "gif"));
+  formats->append(new imageFormat("GIF", "GIF",  "gif"));
 #ifdef HAVE_LIBJPEG
   formats->append(new imageFormat("JFIF", "JPEG", "jpg"));
 #endif
   formats->append(new imageFormat("XPM", "XPM",  "xpm"));
-  formats->append(new imageFormat("ICO", "Icon File",  "ico"));
+  formats->append(new imageFormat("ICO", "Windows Icon File",  "ico"));
 /*
 #ifdef HAVE_LIBJPEG
   QImageIO::defineIOHandler("JFIF","^\377\330\377\340", 0, read_jpeg_jfif, NULL);
