@@ -38,7 +38,7 @@ using namespace KMrmlConfig;
 static const int COL_FILENAME = 1;
 
 typedef KGenericFactory<KCMKMrml, QWidget> MrmlFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_kmrml, MrmlFactory("kmrml") );
+K_EXPORT_COMPONENT_FACTORY( kcm_kmrml, MrmlFactory("kmrml") )
 
 KCMKMrml::KCMKMrml(QWidget *parent, const char *name, const QStringList & ):
     KCModule(MrmlFactory::instance(), parent, name)
