@@ -65,7 +65,7 @@ extern "C"
     void * init_libkmrmlpart() {
         return new KMrml::PartFactory();
     }
-};
+}
 
 KInstance * PartFactory::s_instance = 0L;
 
@@ -464,12 +464,7 @@ void MrmlPart::slotData( KIO::Job *, const QByteArray& data )
         return;
 
     QDomDocument doc;
-    if ( !doc.setContent( QCString(data) ) ) {
-        qDebug("**** OUPS, got non-XML from slave: %s", data.data());
-    }
-    else {
-//         qDebug("*** got Data: %s", doc.toString().latin1());
-    }
+    doc.setContent( data );
 
     if ( !doc.isNull() )
         parseMrml( doc );
