@@ -47,9 +47,9 @@
 #include "previewer.h"
 
 
-FormatDialog::FormatDialog( QWidget *parent, const QString& imgFormat, const char *name )
+FormatDialog::FormatDialog( QWidget *parent, const QString&, const char *name )
    :KDialogBase( parent, name, true,
-                 /* Tabbed,*/ i18n( "Kooka save assistant" ),
+                 /* Tabbed,*/ i18n( "Kooka Save Assistant" ),
 		 Ok|Cancel, Ok )
 
 {
@@ -718,6 +718,131 @@ QString ImgSaver::errorString( ImgSaveStat stat )
 
 }
 
+QString ImgSaver::extension( const KURL& url ) 
+{
+   QString extension = url.fileName();
+   
+   int dotPos = extension.findRev( '.' );
+   if( dotPos > 0 )
+   {
+      int len = extension.length();
+      extension = extension.right( len - dotPos -1 );
+   }
+   else
+   {
+      /* No extension was supplied */
+      extension = QString();
+   }
+   return extension;
+}
+
+
+bool ImgSaver::renameImage( const KURL& fromUrl, KURL& toUrl, bool askExt,  QWidget *overWidget )
+{
+   /* Check if the provided filename has a extension */
+   QString extTo = extension( toUrl );
+   QString extFrom = extension( fromUrl );
+   KURL targetUrl( toUrl );
+
+   if( extTo.isEmpty() && !extFrom.isEmpty() )
+   {
+      /* Ask if the extension should be added */
+      int result = KMessageBox::Yes;
+      QString fName = toUrl.fileName();
+      if( ! fName.endsWith( "." )  )
+      {
+	 fName += ".";
+      }
+      fName += extFrom;
+      
+      if( askExt )
+      {
+
+	 QString s;
+	 s = i18n("The filename you supplied has no file extension.\nShould the correct one be added automatically? ");
+	 s += i18n( "That would result in the new filename: %1" ).arg( fName);
+
+	 result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension missing"),
+					     KStdGuiItem::yes(), KStdGuiItem::no(),
+					     "AutoAddExtensions" );
+      }
+
+      if( result == KMessageBox::Yes )
+      {
+	 targetUrl.setFileName( fName );
+	 kdDebug(28000) << "Rename file to " << targetUrl.prettyURL() << endl;
+      }
+   }
+   else if( !extFrom.isEmpty() && extFrom != extTo )
+   {
+      /* extensions differ -> TODO */
+      KMessageBox::error( overWidget,
+			  i18n("Format changes of images are currently not supported."),
+			  i18n("Wrong extension found" ));
+      return(false);
+   }
+   
+   bool success = false;
+   
+   if( KIO::NetAccess::exists( targetUrl ) )
+   {
+      kdDebug(28000)<< "Target already exists - can not copy" << endl;
+   }
+   else
+   {
+      if( KIO::file_move(fromUrl, targetUrl) )
+      {
+	 success = true;
+      }
+   }
+   return( success );
+}
+
+
+bool ImgSaver::exportImage( const KURL& fromUrl, const KURL& toUrl, QWidget *overWidget )
+{
+
+   /* Check if the provided filename has a extension */
+   QString extTo = extension( toUrl );
+   QString extFrom = extension( fromUrl );
+   KURL targetUrl( toUrl );
+   
+   if( extTo.isEmpty() && !extFrom.isEmpty())
+   {
+      /* Ask if the extension should be added */
+      int result = KMessageBox::Yes;
+      QString fName = toUrl.fileName();
+      if( ! fName.endsWith( "." ))
+	 fName += ".";
+      fName += extFrom;
+
+      QString s;
+      s = i18n("The filename you supplied has no file extension.\nShould the correct one be added automatically? ");
+      s += i18n( "That would result in the new filename: %1" ).arg( fName);
+
+      result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension missing"),
+					  KStdGuiItem::yes(), KStdGuiItem::no(),
+					  "AutoAddExtensions" );
+
+      if( result == KMessageBox::Yes )
+      {
+	 targetUrl.setFileName( fName );
+      }
+   }
+   else if( !extFrom.isEmpty() && extFrom != extTo )
+   {
+      /* extensions differ -> TODO */
+      KMessageBox::error( overWidget, i18n("Format changes of images are currently not supported."),
+			  i18n("Wrong extension found" ));
+      return(false);
+   }
+   
+   KIO::Job *copyjob = KIO::copy( fromUrl, targetUrl, false );
+
+   return( copyjob ? true : false );
+}
+
+
 /* extension needs to be added */
 
 #include "img_saver.moc"
