@@ -1,4 +1,4 @@
-// $Id: areaselect.cpp,v 1.23 2001/10/10 17:57:45 mueller Exp $
+// $Id: areaselect.cpp,v 1.26 2002/09/25 23:45:28 waba Exp $
 
 #include <stdio.h>
 #include <qcursor.h>
@@ -132,7 +132,6 @@ void AreaSelect::mouseReleaseEvent(QMouseEvent *e)
 {
   int x,y;
   QPainter paint;
-  QWMatrix m;
 
 kdDebug(4400) << "AreaSelect::mouseReleaseEvent() handler called\n" << endl;
 
@@ -148,10 +147,9 @@ kdDebug(4400) << "AreaSelect::mouseReleaseEvent() handler called\n" << endl;
 
     paint.end();
 
-    m.scale((float) 100/(canvas->zoom()), (float) 100/(canvas->zoom()));
     paint.begin(canvas->pixmap());
     //    paint.setPen(pen);
-    paint.setWorldMatrix(m);
+    paint.setWorldMatrix(canvas->zoomMatrix());
     paint.setRasterOp(CopyROP);
     canvas->setSelection(QRect(startx, starty, x-startx, y-starty));
     paint.end();
@@ -167,9 +165,9 @@ kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
-QPixmap AreaSelect::pixmap() const
+const char* AreaSelect::pixmap() const
 {
-    return UserIcon("areaselect");
+    return "areaselect";
 }
 
 void 
