@@ -1,4 +1,4 @@
-// $Id: canvas.cpp,v 1.30 2002/03/08 12:50:04 mlaurent Exp $
+// $Id: canvas.cpp,v 1.33 2002/10/30 00:23:47 deller Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -25,9 +25,10 @@ int Canvas::inst = 0;
 Canvas::Canvas(int width, int height, QWidget *parent, const char *name)
   : QWidget(parent, name)
 {
+  setBackgroundMode(NoBackground);
+
   currentTool= 0;
   s= INACTIVE;
-  matrix= new QWMatrix;
   zoomed= 0;
 
   // Create pixmap
@@ -52,10 +53,11 @@ Canvas::Canvas(int width, int height, QWidget *parent, const char *name)
 Canvas::Canvas(const QString & filename, QWidget *parent, const char *name)
   : QWidget(parent, name)
 {
+  setBackgroundMode(NoBackground);
+
   currentTool= 0;
   s= INACTIVE;
   zoomed= 0;
-  matrix= new QWMatrix;
 
   // Create pixmap
   pix= new QPixmap(filename);
@@ -82,7 +84,6 @@ Canvas::~Canvas()
 {
   delete pix;
   delete zoomed;
-  delete matrix;
 }   
 
 bool Canvas::isModified()
@@ -124,34 +125,37 @@ void Canvas::clearSelection()
 
 void Canvas::cut()
 {
-  copy();
+    copy();
 
-  int w  = haveSelection_ ? selection_.right() - selection_.left() : pix->width();
-  int h  = haveSelection_ ? selection_.bottom() - selection_.top() : pix->height();
-  QPixmap p( w, h );
-  p.fill(QColor("white"));
+    int w  = haveSelection_ ? selection_.right() - selection_.left() : pix->width();
+    int h  = haveSelection_ ? selection_.bottom() - selection_.top() : pix->height();
+    if (w <= 0 || h <= 0)
+	return;
+
+    QPixmap p( w, h );
+    p.fill(QColor("white"));
   
-  int x = haveSelection_ ? selection_.left() : 0;
-  int y  = haveSelection_ ? selection_.top() : 0;
-  bitBlt( pix, x, y, &p, 0, 0, w, h, CopyROP);
+    int x = haveSelection_ ? selection_.left() : 0;
+    int y  = haveSelection_ ? selection_.top() : 0;
+    bitBlt( pix, x, y, &p, 0, 0, w, h, CopyROP);
 
-  clearSelection();
-  markModified();
-  updateZoomed();
+    clearSelection();
+    updateZoomed();
 }
 
-
 void Canvas::copy()
-{
-  int x = haveSelection_ ? selection_.left() : 0;
-  int y  = haveSelection_ ? selection_.top() : 0;
-  int w  = haveSelection_ ? selection_.right() - selection_.left() : pix->width();
-  int h  = haveSelection_ ? selection_.bottom() - selection_.top() : pix->height();
-  kdDebug(4400) << "copying: (" << x << ", " << y << ") - (" << w << ", " << h << ")";
+{ 
+    int x = haveSelection_ ? selection_.left() : 0;
+    int y  = haveSelection_ ? selection_.top() : 0;
+    int w  = haveSelection_ ? selection_.right() - selection_.left() : pix->width();
+    int h  = haveSelection_ ? selection_.bottom() - selection_.top() : pix->height();
+    if (w <= 0 || h <= 0)
+	return;
 
-  QPixmap clipboardPix( w, h );
-  bitBlt( &clipboardPix, 0, 0, pix, x, y, w, h, CopyROP);
-  kapp->clipboard()->setPixmap( clipboardPix ); 
+    kdDebug(4400) << "copying: (" << x << ", " << y << ") - (" << w << ", " << h << ")";
+    QPixmap clipboardPix( w, h );
+    bitBlt( &clipboardPix, 0, 0, pix, x, y, w, h, CopyROP);
+    kapp->clipboard()->setPixmap( clipboardPix ); 
 }
 
 void Canvas::paste( int x, int y )
@@ -160,11 +164,35 @@ void Canvas::paste( int x, int y )
     QPixmap clipPix = cb->pixmap();
     if ( !clipPix.isNull() ) {
        bitBlt( pix, x, y, &clipPix, 0, 0, clipPix.width(), clipPix.height(), CopyROP );
-       markModified();
        updateZoomed();
     }
 }
 
+void Canvas::clear()
+{
+    pix->fill(QColor("white"));
+
+    clearSelection();
+    updateZoomed();
+}
+
+void Canvas::undo()
+{
+    KPaintUndoData *data = dynamic_cast<KPaintUndoData*>(undoStack.undo());
+    if (!data)
+	return;
+
+    // TODO: set the pixmap, toolID and zoomID
+}
+
+void Canvas::redo()
+{
+    KPaintUndoData *data = dynamic_cast<KPaintUndoData*>(undoStack.redo());
+    if (!data)
+	return;
+
+    // TODO: set the pixmap, toolID and zoomID
+}
 
 // ---------- ZOOM ------------------------
 
@@ -174,20 +202,24 @@ void Canvas::setZoom(int z)
   int w, h;
 
   zoomFactor= z;
-  matrix->reset();
-  matrix->scale((float) z/100, (float) z/100);
+  matrix.reset();
+  matrix.scale((float) z/100.0, (float) z/100.0);
+
+  rev_matrix.reset();
+  rev_matrix.translate(-0.5, -0.5);
+  rev_matrix.scale(100.0/z, 100.0/z);
 
   if (zoomed != 0)
     delete zoomed;
 
-  w= (int) (pix->width()* ((float) zoomFactor/100));
-  h= (int) (pix->height()*((float) zoomFactor/100));
+  w= (int) (pix->width()* ((float) zoomFactor/100.0));
+  h= (int) (pix->height()*((float) zoomFactor/100.0));
 
   zoomed= new QPixmap(w, h);
   zoomed->fill(QColor("white"));
 
   p.begin(zoomed);
-  p.setWorldMatrix(*matrix);
+  p.setWorldMatrix(matrix);
   p.drawPixmap(0,0,*pix);
   p.end();
 
@@ -206,11 +238,12 @@ void Canvas::updateZoomed()
   zoomed->fill(QColor("white"));
 
   p.begin(zoomed);
-  p.setWorldMatrix(*matrix);
+  p.setWorldMatrix(matrix);
   p.drawPixmap(0,0,*pix);
   p.end();
 
   repaint( false );
+  markModified();
 }
 
 /*
@@ -243,7 +276,7 @@ void Canvas::updateZoomedClipboard()
 
     /* copy to adjusted clipboard using matrix */
     p.begin(&clipboardPix);
-    p.setWorldMatrix(*matrix);
+    p.setWorldMatrix(matrix);
     p.drawPixmap(0,0,*zc);
     p.end();
     
@@ -298,7 +331,7 @@ void Canvas::setPixmap(QPixmap *px)
     zoomed = new QPixmap(w, h);
 
     p.begin(zoomed);
-    p.setWorldMatrix(*matrix);
+    p.setWorldMatrix(matrix);
     p.drawPixmap(0,0,*pix);
     p.end();
 
@@ -325,7 +358,7 @@ void Canvas::setDepth(int d)
     px= new QPixmap(pix->width(), pix->height(), d);
     *px= i;
     setPixmap(px);
-    markModified();
+    updateZoomed();
     delete px;
   }
 }
@@ -347,11 +380,21 @@ void Canvas::resizeImage(int w, int h)
     pix= newpix;
     setZoom(zoom());
     emit pixmapChanged(pix);
-    markModified();
+    updateZoomed();
   }
   repaint(0);
 }
 
+int Canvas::imageWidth() const
+{
+  return pix->width();
+}
+
+int Canvas::imageHeight() const
+{
+  return pix->height();
+}
+
 /* 
     paint Event is the ONLY place where the canvas is
     updated, normally, by copying the offscreen zoomed pixmap
@@ -365,9 +408,13 @@ void Canvas::paintEvent(QPaintEvent *)
 
 void Canvas::mousePressEvent(QMouseEvent *e)
 {
-kdDebug(4400) << "Canvas::mousePressEvent() redirector called\n" << endl;
-  if (isActive())
-    currentTool->mousePressEvent(e);
+    // give Manager the posibillity to update tool settings
+    emit startDrawing();
+
+    kdDebug(4400) << "Canvas::mousePressEvent() redirector called" << endl;
+
+    if (isActive())
+	currentTool->mousePressEvent(e);
 } 
 
 void Canvas::mouseMoveEvent(QMouseEvent *e)
@@ -421,15 +468,19 @@ bool Canvas::load(const QString & filename, const char *format)
 
 bool Canvas::save(const QString & filename, const char *format)
 {
-  bool s;
+	bool s;
+	QString fm(format);
 
-kdDebug(4400) << "Canvas::save() file= " << filename << ", format= " << format << "\n" << endl;
+	kdDebug(4400) << "Canvas::save() file= " << filename << ", format= " << format << "\n" << endl;
 
-  s= pix->save(filename, format);
+	if (fm.isEmpty())	// no format given, use default
+		s= pix->save(filename, "PNG");
+	else
+		s= pix->save(filename, format);
 
-kdDebug(4400) << "Canvas::save() returning " << s << "\n" << endl;
+	kdDebug(4400) << "Canvas::save() returning " << s << "\n" << endl;
 
-  return s;
+	return s;
 }
 
 void Canvas::keyPressEvent(QKeyEvent *e)
@@ -447,5 +498,9 @@ void Canvas::keyReleaseEvent(QKeyEvent *e)
     currentTool->keyReleaseEvent(e);
 }
 
+const QWMatrix &Canvas::zoomMatrix() const
+{
+   return rev_matrix;
+}
 
 #include "canvas.moc"
