@@ -1,4 +1,4 @@
-// $Id: infodialog.cpp,v 1.15 2001/10/10 17:57:45 mueller Exp $
+// $Id: infodialog.cpp,v 1.16 2002/07/03 11:42:54 binner Exp $
 
 #include <qgrid.h>
 #include <qimage.h>
@@ -46,7 +46,7 @@ imageInfoDialog::imageInfoDialog(Canvas *c, QWidget* parent, const char* name)
   // Colour depth
   //
   QLabel *tmpQLabel = new QLabel( info, "Label_3" );
-  tmpQLabel->setText( i18n( "Color Depth:" ) );
+  tmpQLabel->setText( i18n( "Color depth:" ) );
 
   colourDepth = new QLabel( info, "Label_4" );
   QString depthStr;
@@ -58,7 +58,7 @@ imageInfoDialog::imageInfoDialog(Canvas *c, QWidget* parent, const char* name)
   // Colours used
   //
   tmpQLabel = new QLabel( info, "Label_5" );
-  tmpQLabel->setText( i18n("Colors Used:") );
+  tmpQLabel->setText( i18n("Colors used:") );
 
   coloursUsed = new QLabel( info, "Label_6" );
   QString colUseStr;
@@ -67,7 +67,7 @@ imageInfoDialog::imageInfoDialog(Canvas *c, QWidget* parent, const char* name)
   coloursUsed->setAlignment( AlignRight );
 
   //  tmpQLabel = new QLabel( this, "Label_8" );
-  //  tmpQLabel->setText( i18n("Transparent Color:") );
+  //  tmpQLabel->setText( i18n("Transparent color:") );
   //  QLineEdit* tmpQLineEdit;
   //  tmpQLineEdit = new QLineEdit( this, "LineEdit_1" );
 
@@ -75,7 +75,7 @@ imageInfoDialog::imageInfoDialog(Canvas *c, QWidget* parent, const char* name)
   // Image size
   //
   tmpQLabel = new QLabel( info, "Label_9" );
-  tmpQLabel->setText( i18n( "Image Width:" ) );
+  tmpQLabel->setText( i18n( "Image width:" ) );
 
   QSize sz = c->pixmap()->size();
 
@@ -86,7 +86,7 @@ imageInfoDialog::imageInfoDialog(Canvas *c, QWidget* parent, const char* name)
   width->setAlignment( AlignRight );
 
   tmpQLabel = new QLabel( info, "Label_11" );
-  tmpQLabel->setText( i18n("Image Height:") );
+  tmpQLabel->setText( i18n("Image height:") );
 
   height = new QLabel( info, "Label_12" );
   QString heightStr;
