@@ -3,7 +3,7 @@
 /* modified by jha (j.habenicht@usa.net)
  */
 
-// $Id: kpaint.h,v 1.37 2001/11/03 14:22:04 andreas Exp $
+// $Id: kpaint.h,v 1.40 2002/09/02 16:56:27 winkvist Exp $
 
 #ifndef KPAINT_H
 #define KPAINT_H
@@ -59,11 +59,13 @@ public slots:
     void editCut();
     void editPaste();
     void editPasteImage();
+    void editClear();
     void editZoomNormal();
     void editZoomIn();
     void editZoomOut();
     void editOptions();
     void editToolbars();
+    void editKeyBindings();
 
     //Edit Zoom
     void viewZoom( const QString & );
@@ -89,20 +91,8 @@ public slots:
     */
     void readOptions();
 
-    /**
-    * Write the options
-    */
-    void writeOptions();
-
-  /**
-   * Update side toolbar items
-   */
-  void slotSideToolbarMoved();
-
     void enableEditPaste();
 
-    void dummy();
-
 protected:
     // Load/Save files
     bool loadFile(const KURL& url);
@@ -119,10 +109,19 @@ private:
     void initStatus();
     bool initSideBar();
 
-    KAction *revertAction, *copyAction, *cutAction, *pasteAction, *paletteAction,
-      *saveAction, *saveAsAction, *pasteImageAction;
-    KAction *zoomInAction, *zoomOutAction, *zoomNormalAction;
-    KToggleAction *toolbarAction, *statusbarAction;
+    KAction *revertAction;
+    KAction *copyAction;
+    KAction *cutAction;
+    KAction *pasteAction;
+    KAction *paletteAction;
+    KAction *saveAction;
+    KAction *saveAsAction;
+    KAction *pasteImageAction;
+    KAction *zoomInAction;
+    KAction *zoomOutAction;
+    KAction *zoomNormalAction;
+
+    KToggleAction *statusbarAction;
     KSelectAction *zoomAction;
 
     /**
@@ -152,8 +151,8 @@ private:
     KColorButton *rmbColourBtn;
 
     // Child widgets
-    QScrollView *v;
-    Canvas *c;
+    QScrollView *m_view;
+    Canvas *m_canvas;
 
     KToolBar *toolsToolbar;
     KToolBar *commandsToolbar;
@@ -161,7 +160,7 @@ private:
   
     KStatusBar *statusbar;
     KMenuBar *menu;
-    MainView *mv;
+    MainView *m_mainView;
 
     QPixmap *lmbColor, *rmbColor;
     int orig_width;
