@@ -21,13 +21,13 @@
 */
 
 
-#include <qttableview.h>
+#include <qtable.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qimage.h>
 #include <qevent.h>
 
-class paletteWidget : public QtTableView
+class paletteWidget : public QTable
 {
     Q_OBJECT
 
@@ -35,15 +35,13 @@ class paletteWidget : public QtTableView
         paletteWidget(QPixmap *, QWidget *parent= 0, const char *name= 0);
         paletteWidget(QWidget *parent= 0, const char *name= 0);
 
-        void paintCell(QPainter *p, int row, int col);
+        void paintCell(QPainter *p, int row, int col, int width, int height);
 
         void setPixmap(QPixmap *);
         QPixmap *pixmap();
         QImage *img;
         void mousePressEvent(QMouseEvent *e);
 
-        // setColour(int index, QColor c)
-
     public slots:
         void editColour(int);
 
