@@ -1,4 +1,4 @@
-// $Id: pen.cpp,v 1.25 2001/06/14 07:30:06 waba Exp $
+// $Id: pen.cpp,v 1.28 2002/09/25 23:45:28 waba Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -31,7 +31,6 @@ void Pen::mousePressEvent(QMouseEvent *e)
   int x,y;
   QPainter painter1;
   QPainter painter2;
-  QWMatrix m;
 
   kdDebug(4400) << "Pen::mousePressEvent() handler called\n" << endl;
   
@@ -44,29 +43,17 @@ void Pen::mousePressEvent(QMouseEvent *e)
     y= (e->pos()).y();
     activeButton= e->button();
 
-    m.scale((float) 100/(canvas->zoom()), (float) 100/(canvas->zoom()));
-
     painter1.begin(canvas->pixmap());
-
     if (activeButton == LeftButton)
       painter1.setPen(leftpen);
     else
       painter1.setPen(rightpen);
-    painter1.setWorldMatrix(m);
-
-    painter2.begin(canvas->zoomedPixmap());
-
-    if (activeButton == LeftButton)
-      painter2.setPen(leftpen);
-    else
-      painter2.setPen(rightpen);
 
+    painter1.setWorldMatrix(canvas->zoomMatrix());
     painter1.drawPoint(x, y);
-    painter2.drawPoint(x, y);
-
     painter1.end();
-    painter2.end();
 
+    canvas->updateZoomed();
     canvas->repaint(0);
     lastx= x;
     lasty= y;
@@ -83,7 +70,6 @@ void Pen::mouseMoveEvent(QMouseEvent *e)
   int x,y;
   QPainter painter1;
   QPainter painter2;
-  QWMatrix m;
 
   if (isActive()) {
     x= (e->pos()).x();
@@ -91,8 +77,6 @@ void Pen::mouseMoveEvent(QMouseEvent *e)
 
     if (drawing) {
       if ((x != lastx) || (y != lasty)) {
-	m.scale((float) 100/(canvas->zoom()), (float) 100/(canvas->zoom()));
-
 	painter1.begin(canvas->pixmap());
 
 	if (activeButton == LeftButton)
@@ -100,23 +84,14 @@ void Pen::mouseMoveEvent(QMouseEvent *e)
 	else
 	  painter1.setPen(rightpen);
 
-	painter1.setWorldMatrix(m);
-
-	painter2.begin(canvas->zoomedPixmap());
-
-	if (activeButton == LeftButton)
-	  painter2.setPen(leftpen);
-	else
-	  painter2.setPen(rightpen);
-
+	painter1.setWorldMatrix(canvas->zoomMatrix());
 	painter1.drawLine(lastx, lasty, x, y);
-	painter2.drawLine(lastx, lasty, x, y);
 
 	lastx= x;
 	lasty= y;
 
 	painter1.end();
-	painter2.end();
+        canvas->updateZoomed();
 	canvas->repaint(0);
       }
     }
@@ -136,9 +111,9 @@ void Pen::mouseReleaseEvent(QMouseEvent *e)
   }
 }
 
-QPixmap Pen::pixmap() const
+const char* Pen::pixmap() const
 {
-    return UserIcon("pen");
+    return "pencil";
 }
 
 #include "pen.moc"
