@@ -1,13 +1,20 @@
-/****************************************************************************
- ** $Id: kuickshow.h,v 1.11.2.1 2003/01/11 00:25:59 pfeiffer Exp $
- **
- ** KuickShow - a fast and comfortable image viewer based on Rasterman's Imlib
- **
- ** Created : 98
- **
- ** Copyright (C) 1998, 1999 by Carsten Pfeiffer.  All rights reserved.
- **
-****************************************************************************/
+/* This file is part of the KDE project
+   Copyright (C) 1998-2003 Carsten Pfeiffer <pfeiffer@kde.org>
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation, version 2.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+ */
 
 #ifndef KUICKSHOW_H
 #define KUICKSHOW_H
