@@ -15,7 +15,7 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
-// $Id: kview.cpp,v 1.58 2002/11/15 12:39:48 faure Exp $
+// $Id: kview.cpp,v 1.58.2.2 2003/02/11 13:29:34 mkretz Exp $
 
 #include "kview.h"
 #include "kimageviewer/viewer.h"
@@ -107,7 +107,7 @@ KView::KView()
 				m_paRecent, SLOT( addURL( const KURL & ) ) );
 
 		m_paRecent->loadEntries( KGlobal::config() );
-		readSettings(); // KGlobal::config() );
+		readSettings();
 
 		// reload configuration when it's changed by the conf dlg
 		// create conf dlg modules
@@ -230,7 +230,7 @@ void KView::selectionChanged( const QRect & rect )
 
 void KView::contextPress( const QPoint & point )
 {
-	QPopupMenu * pop = ( QPopupMenu* )factory()->container( "popupmenu", this ); 
+	QPopupMenu * pop = ( QPopupMenu* )factory()->container( "popupmenu", this );
 	pop->popup( point );
 }
 
@@ -361,9 +361,6 @@ void KView::slotConfigureToolbars()
 void KView::slotNewToolbarConfig()
 {
 	applyMainWindowSettings( KGlobal::config(), "MainWindow" );
-	createGUI( 0 );
-	createShellGUI( false );
-	createGUI( m_pViewer );
 }
 
 void KView::reloadConfig()
