@@ -15,7 +15,7 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
-// $Id: kimagecanvas.cpp,v 1.22.2.3 2003/02/21 20:39:24 mkretz Exp $
+// $Id: kimagecanvas.cpp,v 1.22.2.4 2003/07/17 15:39:33 mueller Exp $
 
 #include "kimagecanvas.h"
 #include "kimageholder.h"
@@ -38,7 +38,7 @@ const int MOUSECURSORHIDETIME = 3000;
 
 //extern bool qt_use_xrender;
 
-K_EXPORT_COMPONENT_FACTORY( libkviewcanvas, KGenericFactory<KImageCanvas> );
+K_EXPORT_COMPONENT_FACTORY( libkviewcanvas, KGenericFactory<KImageCanvas> )
 
 KImageCanvas::KImageCanvas( QWidget * parent, const char * name, const QStringList & )
 	: QScrollView( parent, name, WResizeNoErase | WStaticContents )
