@@ -63,7 +63,7 @@
 #include <krecentdocument.h>
 
 typedef KParts::GenericFactory<KViewViewer> KViewViewerFactory;
-K_EXPORT_COMPONENT_FACTORY( libkviewviewer, KViewViewerFactory );
+K_EXPORT_COMPONENT_FACTORY( libkviewviewer, KViewViewerFactory )
 
 KViewViewer::KViewViewer( QWidget *parentWidget, const char * /*widgetName*/,
 		QObject *parent, const char *name, const QStringList & )
