@@ -41,7 +41,7 @@ extern "C"
   {
     return new KViewPartFactory;
   }
-};
+}
 
 
 KInstance *KViewPartFactory::s_instance = 0L;
@@ -350,6 +350,12 @@ bool KViewPart::openFile()
 }
 
 
+void KViewPart::reload(void)
+{
+  multiPage->reload();
+}
+
+
 void KViewPart::fileChanged(const QString &file)
 {
   if (file == m_file && watchAct->isChecked())
