@@ -53,6 +53,7 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   // file menu
   KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
   recent = KStdAction::openRecent (this, SLOT(openURL(const KURL &)), actionCollection());
+  reloadAction = new KAction(i18n("Reload"), "reload", CTRL + Key_R, view, SLOT(reload(void)), actionCollection(), "reload");
   closeAction = KStdAction::close(this, SLOT(slotFileClose()), actionCollection());
   KStdAction::quit (this, SLOT(slotQuit()), actionCollection());
 
@@ -92,6 +93,7 @@ void KViewShell::checkActions()
   bool doc = !view->url().isEmpty();
 
   closeAction->setEnabled(doc);
+  reloadAction->setEnabled(doc);
 }
 
 
