@@ -64,7 +64,7 @@ private:
   KRecentFilesAction *recent;
   QString cwd;
 
-  KAction *closeAction;
+  KAction *closeAction, *reloadAction;
   KToggleAction *showtoolbar, *showstatusbar;
 
   KHelpMenu *m_helpMenu;
