@@ -1,31 +1,23 @@
-/***************************************************************************
-                   imgscaledialog.cpp - small dialog to scale the image
-                             -------------------                                         
-    begin                : 04.04.2001
-    copyright            : (C) 1999 by Klaas Freitag
-    email                : freitag@suse.de
+/* This file is part of the KDE Project
+   Copyright (C) 1999 Klaas Freitag <freitag@suse.de>  
 
-    $Id: imgscaledialog.cpp,v 1.4 2001/09/02 08:13:14 malte Exp $ 
-***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: imgscaledialog.cpp,v 1.7 2002/09/19 10:24:10 freitag Exp $
+*/
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -53,7 +45,7 @@ ImgScaleDialog::ImgScaleDialog( QWidget *parent, int curr_sel,
    QButtonGroup *radios = new QButtonGroup ( 2, Qt::Horizontal, this );
    setMainWidget(radios);
    Q_CHECK_PTR(radios);
-   radios->setTitle( i18n("Select image zoom:") );
+   radios->setTitle( i18n("Select Image Zoom") );
    
    connect( radios, SIGNAL( clicked( int )),
 	    this, SLOT( setSelValue( int )));
@@ -108,7 +100,7 @@ ImgScaleDialog::ImgScaleDialog( QWidget *parent, int curr_sel,
    }
    
    // Custom Scaler at the bottom
-   QRadioButton *rbCust = new QRadioButton (i18n ("Custom Scale Factor:"),
+   QRadioButton *rbCust = new QRadioButton (i18n ("Custom scale factor:"),
 					    radios);
    if( ! one_is_selected )
       rbCust->setChecked( true );
